;----------------------------------------------------------
;+
; NAME: ANS_MSHIFT_LOCATION'
; PURPOSE:'
;   Bulk process level-2 data for SHIFTING
; CALLING SEQUENCE:'
;   ans_mshift_location, input_dir, output_dir
; INPUT:'
;   input_dir            = Directory of source files
; OUTPUT:
;   output_file          = Directory of destination files
; KEYWORDS:
;   /quiet       : Do not print intermediate results'
;   /help        : List help.
; MOFICATION HISTORY
;   2014 May 07 Frank Monaldo. Creation
; Copyright (C) 2014, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  

pro ans_mshift_location, input_dir, output_dir    , $
                         quiet       = quiet     , $
                         help        = help       
    
if keyword_set(help) or (n_params(0) lt 1 )  then begin
  print, ' NAME: ANS_MSHIFT_LOCATION'
  print, ' PURPOSE:'
  print, '   Bulk process level-2 data for SHIFTING
  print, ' CALLING SEQUENCE:'
  print, '   ans_mshift_location, input_dir, output_dir
  print, ' INPUT:'
  print, '   input_dir            = Directory of source files
  print, ' OUTPUT:
  print, '   output_file          = Directory of destination files
  print, ' KEYWORDS:
  print, '   /quiet       : Do not print intermediate results'
  print, '   /help        : List help.
  return
endif

!quiet=1
printflag= 1
if keyword_set(quiet) then printflag=1

input_files = file_search(input_dir, '*level2.nc', count=count)

if count eq 0 then begin
  if printflag then print, 'No files found'
  return
endif

n= n_elements(input_files)

for i = 0, n -1 do begin
   infile  = getwrd( input_files[i], 0, /last, del ='/' )
   outfile = output_dir + '/' + infile
   ans_shift_location, input_files[i], outfile, ish, jsh, /quiet
   if ish eq 0  and jsh eq 0 then begin
      futil, input_files[i], to=outfile, /move
   endif else begin
      futil, input_files[i], /delete
   endelse
endfor

end
