;-----------------------------------------------------
;+
; NAME: ANS_READ_ASF_RAW
; PURPOSE:
;   The purpose is the read an ASF data file and return
;   the raw unaverage digital value
; CALLING SEQUENCE:
;
; ans_read_asf_raw, datafile, image, n_pixel, n_line
; INPUT:
;    datafile= string containing data file name.
;    n_pixel=  number of pixel in original image
;    n_line=   number of lines
; OUTPUT:
;    image=    image array
; KEYWORD
;    /quiet    Print no intermediate output.
;    /help     Get help.
;    error=    error      
; MODIFICATION HISTORY:
;    2010 Mar 14 Frank Monaldo
;    2010 Jun 14 Frank Monaldo. Print help on no input
;    2011 Feb 05 Frank Monaldo. Add error keyword
; Copyright (C) 2010, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro ans_read_asf_raw, datafile, image, n_pixel, n_line, help=help, quiet=quiet, error=error	

if keyword_set(help)  or (n_params(0) lt 1 ) then begin
  print, ' NAME: ANS_READ_ASF_RAW
  print, ' PURPOSE:
  print, '   The purpose is the read an ASF data file and return
  print, '   the raw unaverage digital value
  print, ' CALLING SEQUENCE:
  print, '
  print, ' ans_read_asf_data, datafile, image, n_pixel, n_line
  print, ' INPUT:
  print, '    datafile= string containing data file name.
  print, '    n_pixel=  number of pixel in original image
  print, '    n_line=   number of lines
  print, ' OUTPUT:
  print, '    image=    image array
  print, ' KEYWORD
  print, '    /quiet    Print no intermediate output.
  print, '    /help     Get help. 
  return
endif

error= 1

catch, error_status  
;This statement begins the error handler:  

if Error_status ne 0 then begin  
   print, 'error index: ', error_status  
   print, 'error message: ', !error_state.msg  
   if error_status eq -249  or $
      error_status eq -252  or $
      error_status eq -261  or $
      error_status eq -262  then begin
      error= -1
      return
   endif
   ; handle the error by extending a:  
   catch, /cancel  
endif  


printflag=1

if keyword_set(quiet)    then printflag=     0 

header_length= 192
header_length=   192
record_length=   header_length+n_pixel
image=   bytarr(n_pixel, n_line)


;
; Reading data 
;

close, 1
openr, 1, datafile
if printflag then print, 'Reading file '+datafile
header_length=   192
record_length=   header_length+n_pixel
;
; Read first line of information,  no image data included in this line.
;
record=      bytarr(record_length)
image_line=  bytarr(n_pixel)
header=      bytarr(192)
readu,1,record
; 
; Read in image
;
istep= n_line / 10L
for i=0L, n_line-1 do begin
  if i mod istep eq 0 and printflag then print, 'Reading line: ' + string(i, format='(I6)') + ' of ' + string(n_line, format='(I6)')
  readu,1, header, image_line
  image[*,i]= image_line
endfor
close,1    


end
