;----------------------------------------------------------
;+
; NAME: ANS_READ_SIO_DATA'
; PURPOSE:'
;   This program reads data in SIO format. It is essentially an' 
;   essentially flat file preceded with a 20 byte header, This program
;   can be used to read either image or mask data.
; CALLING SEQUENCE:'
;   ans_read_sio_data, filename, image'
; INPUT:'
;   filename=     A string containing the file to read'
; OUTPUT:'
;   image        Two dimensional array (If data type
;                is floating point the units are NRCS
; KEYWORDS:
;    /quiet=      Do not print intermediate results'
;    /help=       List help.'
; MODIFICATION
;   2009 Oct 19 Frank Monaldo, re-write of ws_read_sio.pro
;   2009 Nov 10 Frank Monaldo, added signed integer option for land mask data. 
;               There may be another data_type in the SIO format that will
;               make this unnecssary.
;   2010 Jan 02 Frank Monaldo. Added print out of image size
;   2010 Feb 09 Frank Monaldo. Add option to print help w/no input
;   2010 Feb 09 Frank Monaldo. Corrected spelling.
;   2010 May 23 Frank Monaldo. Add some hlp statements
;   2010 Dec 29 Frank Monaldo. Removed an unnecessary hlp, image commmand
;   2011 Nov 14 Frank Monaldo. Changed data type code 2= signed integer
;   2013 Jan 03 Frank Monaldo. Add ability to read unsigned, one-byte integer
; Copyright (C) 2007-2010, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro  ans_read_sio_data, filename, image, quiet=quiet, help=help


if keyword_set(help)  or (n_params(0) lt 1) then begin
  print, ' NAME: ANS_READ_SIO_DATA'
  print, ' PURPOSE:'
  print, '   This program reads data in SIO format. It is essentially an' 
  print, '   essentially flat file preceded with a 20 byte header, This program
  print, '   can be used to read either image or mask data.
  print, ' CALLING SEQUENCE:'
  print, '   ans_read_sio_data,  filename, image'
  print, ' INPUT:'
  print, '   filename=     A string containing the file to read'
  print, ' OUTPUT:'
  print, '   image        Two dimensional array (If data type
  print, '                is floating point the units are NRCS
  print, ' KEYWORDS:
  print, '    /quiet=      Do not print intermediate results'
  print, '    /help=       List help.'
  return
endif

printflag=1
if keyword_set(quiet) then printflag=0

if printflag then print, 'Input filename: ' + filename + '.'

magic_number= -16678914L
nx=            long(0)
ny=            long(0)
data_type=     0L
byte_size=     0L
;
; Need to open file and fill in the header data here.
;
if printflag then print, 'Opening ' + filename + '.'
close,  1
openr,  1, filename
;readu,  1, magic_number, nx, ny, data_type, byte_size ; Orignal Line
;Note the ny, nx order had to be changed to work C.Jackson 
readu,  1, magic_number, ny, nx, data_type, byte_size
;
; Note that file is still open
;
; We have not implemented all possible combinations
;
case data_type of
3L:   begin   ; Four byte floating pooint
        if byte_size ne 4 then begin
          print, 'The data type is:', data_type
          print, 'The byte size is:', byte_size
          print, 'The program does not know how to handle these data.'
          close, 1 
          return
        endif
        image= fltarr(nx, ny)
        tt= 'four-byte floating point data'
      end
1L:   begin   ;  Unsigned integer
        if byte_size eq 1 then begin
          image= bytarr(nx, ny)
          tt= 'one-byte unsigned integer'
        endif else begin
          image= uintarr(nx, ny)
          tt= 'two-byte unsigned integer'
        endelse
      end
2L:   begin  ;  Signed  integer
        if byte_size ne 2 then begin
          print, 'The data type is:', data_type
          print, 'The byte size is:', byte_size
          print, 'The program does not know how to handle thes data.'
          close, 1 
          return
        endif
        if byte_size eq 2 then begin
          image= intarr(nx, ny)
          tt= 'two-byte signed integer'
        endif else begin
          image= lonarr(nx, ny)
          tt= 'four-byte unsigned integer'
        endelse
      end
ELSE: begin
        print, 'The data type is:', data_type
        print, 'The byte size is:', byte_size
        print, 'The program does not know how to handle these data.'
        close, 1 
        return
      end
endcase

if printflag then print, 'Starting to read ' + tt + ' from ' + filename
readu, 1, image
close, 1


end
