;+---------------------------
; NAME: ANS_READ_UAVSAR_ANCIL_IMG
; PURPOSE:
;    The purpose of this program is to read the UAVSAR data files
; CALLING SEQUENCE:   
;    ans_read_uavsar_ancil_img, file, ancil, $
;                     slcHH      = slcHH   , $   
;                     slcHV      = slcHV   , $   
;                     slcVH      = slcVH   , $   
;                     slcVV      = slcVV   , $   
;                     mlcHHHH    = mlcHHHH , $   
;                     mlcHVHV    = mlcHVHV , $   
;                     mlcVVVV    = mlcVVVV , $   
;                     mlcHHHV    = mlcHHHV , $   
;                     mlcHHVV    = mlcHHVV , $   
;                     mlcHVVV    = mlcHVVV , $   
;                     grdHHHH    = grdHHHH , $   
;                     grdHVHV    = grdHVHV , $   
;                     grdVVVV    = grdVVVV , $   
;                     grdHHHV    = grdHHHV , $   
;                     grdHHVV    = grdHHVV , $   
;                     grdHVVV    = grdHVVV , $   
;                     hgt        = hgt     , $    
;                     inc        = inc     , $   
;                     slope      = slope     
; INPUT:
;    file         = UAVSAR SAR ancillary data file
;                   e.g. NISARP_20706_19078_009_191016_L090
;                   NISARP  = Target name
;                   20706   = 207 (heading) 06 (incremented alphanumeric)
;                   19078   = 19 (year) 078 (flight of the year)
;                   009     = Flight line
;                   191016  = 19 (year) 10 (month) 16 (day)
;                   L090    = L (band) 090 (stearing angle)
; OUTPUT:
;    ancil         = ancillary data structure          
;    slcHH        = Slant range complex  HH  
;    slcHV        = Slant range complex  HV  
;    slcVH        = Slant range complex  VH  
;    slcVV        = Slant range complex  VV  
;    mlcHHHH      = Multi look complex   HHHH     
;    mlcHVHV      = Multi look complex   HVHV     
;    mlcVVVV      = Multi look complex   VVVV     
;    mlcHHHV      = Multi look complex   HHHV     
;    mlcHHVV      = Multi look complex   HHVV     
;    mlcHVVV      = Multi look complex   HVVV     
;    grdHHHH      = Ground range         HHHH     
;    grdHVHV      = Ground range         HVHV     
;    grdVVVV      = Ground range         VVVV     
;    grdHHHV      = Ground range         HHHV     
;    grdHHVV      = Ground range         HHVV     
;    grdHVVV      = Ground range         HVVV     
;    hgt          = Height         
;    inc          = Incident angle
;    slope        = Slope     

; KEYWORDS:
;     /quiet     = Do not print intermediate results.
;     /help      = Print out help
;     /display   = Display Xwindow of arrays
;     error      = <0 is bad
;                  -1 return from help
;                  -2 No ancillary data file
;                  -3 No incident angle file
;                  -4 No slope          file
;                  -5 No HHHH           file
;                  -6 No VVVV           file
;                  -7 No HVHV           file
;                  -8 No HHHV           file
;                  -9 No HHVV           file
;                 -10 No HVVV           file
;  2019 Dec 12 Frank Monaldo. Creation
; Copyright (C) 2019, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.   
;-
;

pro ans_read_uavsar_ancil_img, file, ancil, $
                     slcHH      = slcHH   , $   
                     slcHV      = slcHV   , $   
                     slcVH      = slcVH   , $   
                     slcVV      = slcVV   , $   
                     mlcHHHH    = mlcHHHH , $   
                     mlcHVHV    = mlcHVHV , $   
                     mlcVVVV    = mlcVVVV , $   
                     mlcHHHV    = mlcHHHV , $   
                     mlcHHVV    = mlcHHVV , $   
                     mlcHVVV    = mlcHVVV , $   
                     grdHHHH    = grdHHHH , $   
                     grdHVHV    = grdHVHV , $   
                     grdVVVV    = grdVVVV , $   
                     grdHHHV    = grdHHHV , $   
                     grdHHVV    = grdHHVV , $   
                     grdHVVV    = grdHVVV , $   
                     hgt        = hgt     , $    
                     inc        = inc     , $   
                     slope      = slope   , $  
                     display    = display , $
                     quiet      = quiet   , $
                     help       = help    , $
                     error      = error
                    
error=     0

if keyword_set(help) or (n_params(0) lt 1 ) then begin
  print, 'NAME: ANS_READ_UAVSAR
  print, 'PURPOSE:
  print, '   The purpose of this program is to read the UAVSAR data files
  print, 'CALLING SEQUENCE:   
  print, '   ans_read_uavsar_ancil_img, file, ancil, $
  print, '                    slcHH      = slcHH   , $   
  print, '                    slcHV      = slcHV   , $   
  print, '                    slcVH      = slcVH   , $   
  print, '                    slcVV      = slcVV   , $   
  print, '                    mlcHHHH    = mlcHHHH , $   
  print, '                    mlcHVHV    = mlcHVHV , $   
  print, '                    mlcVVVV    = mlcVVVV , $   
  print, '                    mlcHHHV    = mlcHHHV , $   
  print, '                    mlcHHVV    = mlcHHVV , $   
  print, '                    mlcHVVV    = mlcHVVV , $   
  print, '                    grdHHHH    = grdHHHH , $   
  print, '                    grdHVHV    = grdHVHV , $   
  print, '                    grdVVVV    = grdVVVV , $   
  print, '                    grdHHHV    = grdHHHV , $   
  print, '                    grdHHVV    = grdHHVV , $   
  print, '                    grdHVVV    = grdHVVV , $   
  print, '                    hgt        = hgt     , $    
  print, '                    inc        = inc     , $   
  print, '                    slope      = slope     
  print, 'INPUT:
  print, '   file         = UAVSAR SAR ancillary data file
  print, '                  e.g. NISARP_20706_19078_009_191016_L090
  print, '                  NISARP  = Target name
  print, '                  20706   = 207 (heading) 06 (incremented alphanumeric)
  print, '                  19078   = 19 (year) 078 (flight of the year)
  print, '                  009     = Flight line
  print, '                  191016  = 19 (year) 10 (month) 16 (day)
  print, '                  L090    = L (band) 090 (stearing angle)
  print, 'OUTPUT:
  print, '   ancil         = ancillary data structure          
  print, '   slcHH        = Slant range complex  HH  
  print, '   slcHV        = Slant range complex  HV  
  print, '   slcVH        = Slant range complex  VH  
  print, '   slcVV        = Slant range complex  VV  
  print, '   mlcHHHH      = Multi look complex   HHHH     
  print, '   mlcHVHV      = Multi look complex   HVHV     
  print, '   mlcVVVV      = Multi look complex   VVVV     
  print, '   mlcHHHV      = Multi look complex   HHHV     
  print, '   mlcHHVV      = Multi look complex   HHVV     
  print, '   mlcHVVV      = Multi look complex   HVVV     
  print, '   grdHHHH      = Ground range         HHHH     
  print, '   grdHVHV      = Ground range         HVHV     
  print, '   grdVVVV      = Ground range         VVVV     
  print, '   grdHHHV      = Ground range         HHHV     
  print, '   grdHHVV      = Ground range         HHVV     
  print, '   grdHVVV      = Ground range         HVVV     
  print, '   hgt          = Height         
  print, '   inc          = Incident angle
  print, '   slope        = Slope     
  print, '
  print, 'KEYWORDS:
  print, '    /quiet      = Do not print intermediate results.
  print, '    /help       = Print out help
  print, '    /display    = Display Xwindow of arrays
  print, '     error      = <0 is bad
  print, '                  -1 return from help
  print, '                  -2 No ancillary data file
  print, '                  -3 No incident angle file
  print, '                  -4 No slope          file
  print, '                  -5 No HHHH           file
  print, '                  -6 No VVVV           file
  print, '                  -7 No HVHV           file
  print, '                  -8 No HHHV           file
  print, '                  -9 No HHVV           file
  print, '                 -10 No HVVV           file
  error= -1
  return
endif
;
; Parcing input parameters
;
error     = 1
printflag = 1
if keyword_set(quiet) then printflag=0
quiet= printflag eq 0

ans_read_uavsar_ancil, file , ancil, quiet = quiet , error = error
if error lt 0 then begin
  error = -2
  if printflag then begin
    print, 'Cannot read ancillary data file
    print, 'Exiting ans_read_uavsar_ancil_img' 
  endif
  return
endif


;
; compute file names
; 
filebreak, file, directory = directory, name  = name

; 
; Assign filenames
file_slcHH   = strcompress( directory + tag_value( ancil,'slcHH'  ) , /remove_all )                         
file_slcHV   = strcompress( directory + tag_value( ancil,'slcHV'  ) , /remove_all )                         
file_slcVH   = strcompress( directory + tag_value( ancil,'slcVH'  ) , /remove_all )                         
file_slcVV   = strcompress( directory + tag_value( ancil,'slcVV'  ) , /remove_all )                        
file_mlcHHHH = strcompress( directory + tag_value( ancil,'mlcHHHH') , /remove_all )                         
file_mlcHVHV = strcompress( directory + tag_value( ancil,'mlcHVHV') , /remove_all )                         
file_mlcVVVV = strcompress( directory + tag_value( ancil,'mlcVVVV') , /remove_all )                         
file_mlcHHHV = strcompress( directory + tag_value( ancil,'mlcHHHV') , /remove_all )                         
file_mlcHHVV = strcompress( directory + tag_value( ancil,'mlcHHVV') , /remove_all )                        
file_mlcHVVV = strcompress( directory + tag_value( ancil,'mlcHVVV') , /remove_all )                                                       
file_grdHHHH = strcompress( directory + tag_value( ancil,'grdHHHH') , /remove_all )                         
file_grdHVHV = strcompress( directory + tag_value( ancil,'grdHVHV') , /remove_all )                         
file_grdVVVV = strcompress( directory + tag_value( ancil,'grdVVVV') , /remove_all )                         
file_grdHHHV = strcompress( directory + tag_value( ancil,'grdHHHV') , /remove_all )                         
file_grdHHVV = strcompress( directory + tag_value( ancil,'grdHHVV') , /remove_all )                         
file_grdHVVV = strcompress( directory + tag_value( ancil,'grdHVVV') , /remove_all )                         
file_hgt     = strcompress( directory + tag_value( ancil,'hgt'    ) , /remove_all )    + '.tif'     
file_hgt     = stress(file_hgt , 'R', 0, '.hgt'  ,'_hgt', ned)                                    
file_inc     = strcompress( directory + tag_value( ancil,'inc'    ) , /remove_all )                         
file_slope   = strcompress( directory + tag_value( ancil,'slope'  ) , /remove_all )

;
; 
; Incident angle
;
if n_elements(inc) gt 0 then begin
  if file_test(file_inc) then begin
    ans_read_uavsar_incid, file_inc, inc, long(ancil.inc_set_cols_pixels) , $                 
                                          long(ancil.inc_set_rows_pixels) , $
                                          quiet = quiet                   , $
                                          error = error
    if error lt 0 then begin
      error = -3
      if printflag then print, 'Cannot read incident angle file
      return
    endif else begin
      inc = reverse(inc,2)
      if keyword_set(display) then begin
        s  = max( [long(ancil.inc_set_cols_pixels) , long(ancil.inc_set_rows_pixels), 1 ])
        s  = long(s/1000)
        tvscl, congrid(inc, long(ancil.inc_set_cols_pixels)/s, long(ancil.inc_set_rows_pixels)/s ) > 0
        print, 'Inc'
        stop
      endif
    endelse
  endif ; End test if file exists
endif   ; If inc is set

;
; 
; Height
;
if n_elements(hgt) gt 0 then begin
  if file_test( file_hgt ) then begin
    hgt = read_tiff( file_hgt )
    hgt = reverse(hgt,2)
    if keyword_set(display) then begin
       s  = max( [long(ancil.hgt_set_cols_pixels) , long(ancil.hgt_set_rows_pixels), 1 ])
       s  = long(s/1000)
       tvscl, congrid(hgt, long(ancil.hgt_set_cols_pixels)/s, long(ancil.hgt_set_rows_pixels)/s ) > 0
       print, 'hgt'
       stop
    endif
  endif else begin
    error = -3
    if printflag then begin
      print, 'Cannot read height file file
      print, 'Exiting ans_read_uavsar 
    endif
    return
  endelse
endif
;
; Slope
;
if n_elements(slope) gt 0 then begin
  if file_test(file_slope) then begin
     ans_read_uavsar_slope, file_slope, slope_east, slope_north, long(ancil.slope_set_cols_pixels) , $                 
                                                                 long(ancil.slope_set_rows_pixels) , $
                                                                 quiet = quiet                     , $
                                                                 error = error
     if error lt 0 then begin
       error = -4
       if printflag then print, 'Cannot read incident angle file'
       return
     endif else begin
       slope_east   = reverse(slope_east ,2)
       slope_north  = reverse(slope_north,2)
       slope = complex( slope_east, slope_north)
       if keyword_set(display) then begin
         s  = max( [long(ancil.slope_set_cols_pixels) , long(ancil.slope_set_rows_pixels), 1 ])
         s  = long(s/500)
         tvscl, congrid( slope_east , long(ancil.slope_set_cols_pixels)/s, long(ancil.slope_set_cols_pixels)/s  )> (-1) < 1
         tvscl, congrid( slope_north, long(ancil.slope_set_cols_pixels)/s, long(ancil.slope_set_cols_pixels)/s  )> (-1) < 1, 500, 0     
         print, 'Slope'
         stop
        endif
        return
     endelse
  endif   ; If slope file exits                              
endif     ; If slope set
;
; grdHHHH
;
if n_elements(grdHHHH) gt 0 then begin
  ans_read_uavsar_grd, file_grdHHHH, grdHHHH, long(ancil.grd_pwr_set_cols_pixels) , $
                                              long(ancil.grd_pwr_set_rows_pixels) , $                                                           
                                              quiet = quiet                       , $
                                              error = error
  if error lt 0 then begin
    error = -5
    if printflag then begin
      print, 'Cannot read grdHHHH file
      print, 'Exiting ans_read_uavsar 
    endif
    return
  endif
  grdHHHH = reverse(grdHHHH,2)
  if keyword_set(display) then begin
     s  = max( [long(ancil.grd_pwr_set_cols_pixels) , long(ancil.grd_pwr_set_rows_pixels), 1 ])
     s  = long(s/1000)
     tvscl, ls(congrid( smooth(grdHHHH,[s,s]) , long(ancil.grd_pwr_set_cols_pixels)/s, long(ancil.grd_pwr_set_rows_pixels)/s ))
     print, 'grdHHHH'
     stop
  endif
endif
;
; grdVVVV
;
if n_elements(grdVVVV) gt 0 then begin
  ans_read_uavsar_grd, file_grdVVVV, grdVVVV, long(ancil.grd_pwr_set_cols_pixels) , $                 
                                              long(ancil.grd_pwr_set_rows_pixels) , $
                                               quiet = quiet                      , $
                                               error = error
  if error lt 0 then begin
    error = -6
    if printflag then begin
      print, 'Cannot read grdVVVV file
      print, 'Exiting ans_read_uavsar 
    endif
    return
  endif
  grdVVVV = reverse(grdVVVV,2)
  if keyword_set(display) then begin
     s  = max( [long(ancil.grd_pwr_set_cols_pixels) , long(ancil.grd_pwr_set_rows_pixels), 1 ])
     s  = long(s/1000)
      tvscl, ls(congrid( smooth(grdVVVV,[s,s]) , long(ancil.grd_pwr_set_cols_pixels)/s, long(ancil.grd_pwr_set_rows_pixels)/s ))
     print, 'grdVVVV'
     stop   
  endif                                        
endif
;
; grdHVHV
;
if n_elements(grdHVHV) gt 0 then begin
  ans_read_uavsar_grd, file_grdHVHV, grdHVHV, long(ancil.grd_pwr_set_cols_pixels) , $                 
                                              long(ancil.grd_pwr_set_rows_pixels) , $
                                               quiet = quiet                      , $
                                               error = error
  if error lt 0 then begin
    error = -7
    if printflag then begin
      print, 'Cannot read grdHVHV file
      print, 'Exiting ans_read_uavsar 
    endif
    return
  endif
  grdHVHV = reverse(grdHVHV,2)
  if keyword_set(display) then begin
     s  = max( [long(ancil.grd_pwr_set_cols_pixels) , long(ancil.grd_pwr_set_rows_pixels), 1 ])
     s  = long(s/1000)
     tvscl, ls(congrid( smooth(grdHVHV,[s,s]) , long(ancil.grd_pwr_set_cols_pixels)/s, long(ancil.grd_pwr_set_rows_pixels)/s ))
     print, 'grdHVHV'
     stop   
  endif
endif
;
; grdHVHV
;
if n_elements(grdHHHV) gt 0 then begin
  ans_read_uavsar_grd, file_grdHHHV, grdHHHV, long(ancil.grd_pwr_set_cols_pixels) , $                 
                                              long(ancil.grd_pwr_set_rows_pixels) , $
                                               quiet = quiet                      , $
                                               error = error
  if error lt 0 then begin
    error = -8
    if printflag then begin
      print, 'Cannot read grdHHHV file
      print, 'Exiting ans_read_uavsar 
    endif
    return
  endif
  grdHHHV = reverse(grdHHHV,2)
  if keyword_set(display) then begin
     s  = max( [long(ancil.grd_pwr_set_cols_pixels) , long(ancil.grd_pwr_set_rows_pixels), 1 ])
     s  = long(s/1000)
     tvscl, ls(congrid( smooth(abs(grdHHHV),[s,s]) , long(ancil.grd_pwr_set_cols_pixels)/s, long(ancil.grd_pwr_set_rows_pixels)/s ))
     print, 'grdHHHV'
     stop   
  endif
endif
;
; grdHHVV
;
if n_elements(grdHHVV) gt 0 then begin
  ans_read_uavsar_grd, file_grdHHVV, grdHHVV, long(ancil.grd_pwr_set_cols_pixels) , $                 
                                              long(ancil.grd_pwr_set_rows_pixels) , $
                                               quiet = quiet                      , $
                                               error = error
  if error lt 0 then begin
    error = -9
    if printflag then begin
      print, 'Cannot read grdHHVV file
      print, 'Exiting ans_read_uavsar 
    endif
    return
  endif
  grdHHVV = reverse(grdHHVV,2)
  if keyword_set(display) then begin
     s  = max( [long(ancil.grd_pwr_set_cols_pixels) , long(ancil.grd_pwr_set_rows_pixels), 1 ])
     s  = long(s/1000)
     tvscl, ls(congrid( smooth(abs(grdHHVV),[s,s]) , long(ancil.grd_pwr_set_cols_pixels)/s, long(ancil.grd_pwr_set_rows_pixels)/s ))
     print, 'grdHHVV'
     stop   
  endif  
endif
;
; grdHVVV
;
if n_elements(grdHVVV) gt 0 then begin
  ans_read_uavsar_grd, file_grdHVVV, grdHVVV, long(ancil.grd_pwr_set_cols_pixels) , $                 
                                              long(ancil.grd_pwr_set_rows_pixels) , $
                                              quiet = quiet                      , $
                                              error = error
  if error lt 0 then begin
    error = -10
    if printflag then begin
      print, 'Cannot read grdHVVV file
      print, 'Exiting ans_read_uavsar 
    endif
    return
  endif
  grdHVVV = reverse(grdHVVV,2)
  if keyword_set(display) then begin
     s  = max( [long(ancil.grd_pwr_set_cols_pixels) , long(ancil.grd_pwr_set_rows_pixels), 1 ])
     s  = long(s/1000)
     tvscl, ls(congrid( smooth(abs(grdHVVV),[s,s]) , long(ancil.grd_pwr_set_cols_pixels)/s, long(ancil.grd_pwr_set_rows_pixels)/s ))
     print, 'grdHVVV'
     stop   
  endif 
endif


       
end
