;+---------------------------
; NAME: ANS_READ_UAVSAR_INCID
; PURPOSE:
;    The purpose of this program is to read the UAVSAR incident angle
;    data
; CALLING SEQUENCE:   
;    ans_read_uavsar_incid, file, incid, nx, ny
; INPUT:
;    file  = UAVSAR *.inc data file
;    nx    = columns
;    ny    = rows
; OUTPUT:          
;    incid = Incident angle in radians
; KEYWORDS:
;     /quiet   = Do not print intermediate results.
;     /help    = Print out help
;     error    = <0 is bad
;                -1 return from help
;                -2 No incident angle file incident angle file
;  2019 Dec 10 Frank Monaldo. Creation
;  2020 Jan 22 Frank Monaldo. Flipping image vertically. 
; Copyright (C) 2019, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.   
;-
;

pro   ans_read_uavsar_incid, file, incid, nx, ny , $
                            quiet   = quiet , $
                            help    = help  , $
                            error   = error
                    
error=     0
if keyword_set(help) or (n_params(0) lt 1 ) then begin
  print, ' NAME: ANS_READ_UAVSAR_INCID
  print, ' PURPOSE:
  print, '    The purpose of this program is to read the UAVSAR incident angle
  print, '    data
  print, ' CALLING SEQUENCE:   
  print, '    ans_read_uavsar_incid, file, incid, nx, ny
  print, ' INPUT:
  print, '    file  = UAVSAR *.inc data file
  print, '    nx    = columns
  print, '    ny    = rows
  print, ' OUTPUT:          
  print, '    incid = Incident angle in radians
  print, ' KEYWORDS:
  print, '     /quiet   = Do not print intermediate results.
  print, '     /help    = Print out help
  print, '     error    = <0 is bad
  print, '                -1 return from help
  print, '                -2  No incident angle file incident angle file
  error= -1
  return
endif
;
; Parcing input parameters
;
error     = 1
printflag = 1
if keyword_set(quiet) then printflag=0
quiet= printflag eq 0


if file_test(file) eq 0 then begin
  error = -2
  if printflag then begin
    print, 'Cannot find file : ' + file
    print, 'Exiting ans_read_uavsar_incid'
  endif
  return
endif 

incid= fltarr(nx, ny)

if printflag then print, 'Start reading file : ' + file

close,  1
openr,  1, file
readu,  1, incid
close,  1
;
; Flipping image
;
if printflag then print, 'End   reading file : ' + file
incid  = reverse(incid, 2)
end
