;----------------------------------------------------------
;+
; NAME: ANS_SHIFT_LOCATION'
; PURPOSE:'
;   Read Level-2 SAR wind retrieval data and display land mask and wind to check for
;   alignment.
; CALLING SEQUENCE:'
;   ans_shift_location, input_file, output_file, ish, jsh
; INPUT:'
;   input_file           = Input Level 2 net cdffile
; OUTPUT:
;   ouput_file           = Corrected Level-2 netCDF file
;   ish                  = i shift
;   jsh                  = j shift
; KEYWORDS:
;   /quiet       : Do not print intermediate results'
;   /help        : List help.
; MOFICATION HISTORY
;   2014 May 07 Frank Monaldo. Creation
; Copyright (C) 2014, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-


pro ans_shift_location, input_file, output_file, ish, jsh, $
                        quiet       = quiet       , $
                        help        = help       
    
                       
if keyword_set(help) or (n_params(0) lt 1 )  then begin
  print, ' NAME: ANS_SHIFT_LOCATION'
  print, ' PURPOSE:'
  print, '   Read Level-2 SAR wind retrieval data and display land mask and wind to check for
  print, '   alignment.
  print, ' CALLING SEQUENCE:'
  print, '   ans_shift_location, input_file, output_file, ish, jsh
  print, ' INPUT:'
  print, '   input_file           = Input Level 2 net cdffile
  print, ' OUTPUT:
  print, '   ouput_file           = Corrected Level-2 netCDF file
  print, '   ish                  = i shift
  print, '   jsh                  = j shift
  print, ' KEYWORDS:
  print, '   /quiet       : Do not print intermediate results'
  print, '   /help        : List help.
  return
endif

!quiet=1
printflag= 1
if keyword_set(quiet) then printflag=1

ans_read_wind_l2_cdf, input_file, info, sigma, sar_wind, input_dir, model_speed, mask, $
                      icemask = icemask , $
                       quiet=quiet                  
 
cont   =  'Y'
ish    =  0
jsh    =  0
buffer =  100
img    =  fltarr(info.nx + buffer, info.ny + buffer)
ni     =  info.nx + buffer
nj     =  info.ny + buffer
istep  =  info.ny /10
jstep  =  info.ny /10
while strupcase(cont) eq 'Y' do begin
   img      = img * 0.0
   imin_msk = buffer / 2  
   jmin_msk = buffer / 2
   cc=0  
   for i=0, info.nx -1l do begin
     for j=0, info.ny -1l do begin
          ii  = imin_msk + ish + i  
          jj  = jmin_msk + jsh + j   
          if ii ge 0   and $
             jj gt 0   and $
             ii lt ni  and $
             jj lt nj  then img[ii,jj] = sar_wind[i,j]
      endfor
   endfor
   for i=0, info.nx -1l do begin
     for j=0, info.ny -1l do begin
        ii  = imin_msk + i  
        jj  = jmin_msk + j 
        if ii        ge 0   and $
           jj        gt 0   and $
           ii        lt ni  and $
           jj        lt nj  and $
           mask[i,j] ge 0  then img[ ii, jj] = 25    
     endfor
   endfor
   erase,0
   w = where( img eq 25, c25) & print, c25
   tvscl, ls(img)
   prompt_ans, 'Do you want another shift', cont, 's', /upcase
   if strupcase(cont) eq 'Y' then begin
       prompt_ans, 'Input i shift            :', ish  , 'i'
       prompt_ans, 'Input j shift            :', jsh  , 'i'
   endif
endwhile

;
;  Resample the SAR wind
;  to the appropriate geophysical cooridnates.
;
sar_wind2    =  sar_wind * 0
for i=0, info.nx - 1L do begin
   for j=0, info.ny - 1L do begin
     ii  = i + ish
     jj  = j + jsh
     if ii ge 0        and $
        jj ge 0        and $
        ii lt info.nx  and $
        jj lt info.ny  then begin  
        sar_wind2[ii, jj] = sar_wind[i,j]
     endif
   endfor
endfor

if ish gt 0 or jsh gt 0 then begin
  ans_write_level2_wind, info, sigma, sar_wind, input_dir, model_speed, mask, icemask, output_file,  $
                          quiet=quiet
endif
end
