;----------------------------------------------------------
;+
; NAME: ANS_SIO2LONLAT'
; PURPOSE:'
;   This program reads data in SIO infor and returns the longitude
;   latitude for the corner
; CALLING SEQUENCE:'
;   ans_sio2lonlat,  infofile, longitude, latitude, i, j
; INPUT:'
;   infofile=     The name of the SIO info file
; OUTPUT:'
;   longitude, latitude for indices, i, j
; KEYWORDS:
;    /quiet=      Do not print intermediate results'
;    /help=       List help.'
; MODIFICATION
;    2010 Oct 11 Frank Monaldo. 
; Copyright (C) 2010, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro  ans_sio2lonlat,  infofile, longitude, latitude, i, j,            $
                      quiet=quiet, help=help


if keyword_set(help) or (n_params(0) lt 1) then begin
  print, ' NAME: ANS_SIO2LONLAT'
  print, ' PURPOSE:'
  print, '   This program reads data in SIO infor and returns the longitude
  print, '   latitude for the corner
  print, ' CALLING SEQUENCE:'
  print, '   ans_sio2lonlat,  infofile, longitude, latitude, i, j
  print, ' INPUT:'
  print, '   infofile=     The name of the SIO info file
  print, ' OUTPUT:'
  print, '   longitude, latitude for indices, i, j
  print, ' KEYWORDS:
  print, '    /quiet=      Do not print intermediate results'
  print, '    /help=       List help.'
  return
endif

printflag=1
if keyword_set(quiet) then printflag=0
quiet= printflag eq 0
;
; Reading in data
;
res= file_search(infofile, count=count)
if count eq 0 then begin
  print, 'Cannot find data file:' + infofile
  print, 'Exiting ans_sio2longlat...'
  return
endif

ans_read_sio_info, infofile, info

ny=            long(info.LINES_SIO_IMAGE) 
nx=            long(info.PIXELS_SIO_IMAGE)
longitude=     fltarr(4)
latitude=      fltarr(4)
i=             [0.0D, nx-1.,  nx-1.,  0.]
j=             [0.0D,    0.,   ny,    ny]

longitude= float( ans_poly_cal(i, j, info.lon_coef, info.lon_xexp, info.lon_yexp) )
latitude=  float( ans_poly_cal(i, j, info.lat_coef, info.lat_xexp, info.lat_yexp) )
 

end
