;----------------------------------------------------------
;+
; NAME: ANS_SIO_IMAGE_TO_VARIANCE'
; PURPOSE:'
;   To read an SIO image file and convert to an equivalently
;   sized variance file.
; CALLING SEQUENCE:'
;   ans_sio_image_to_variance, infile, outfile'
; INPUT:'
;   infile     =    A string containing the file to read'
; OUTPUT:'  
;   outfile    =    Output file namem
; KEYWORDS:  
;    /quiet    =    Do not print intermediate results'
;    /help     =    List help.'
;    halfwidth =    halfwidth
;    error     =    <0 if bad
; MODIFICATION
;   2017 Aug 10 Frank Monaldo Creation
; Copyright (C) 2017, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro  ans_sio_image_to_variance, infile,     outfile    , $
                                halfwidth = halfwidth  , $
                                quiet     = quiet      , $
                                help      = help       , $
                                error     = error

error = 1

if keyword_set(help)  or (n_params(0) lt 1) then begin
  print, ' NAME: ANS_SIO_IMAGE_TO_VARIANCE'
  print, ' PURPOSE:'
  print, '   To read an SIO image file and convert to an equivalently
  print, '   sized variance file.
  print, ' CALLING SEQUENCE:'
  print, '   ans_sio_image_to_variance, infile, outfile'
  print, ' INPUT:'
  print, '   infile     =    A string containing the file to read'
  print, ' OUTPUT:'  
  print, '   outfile    =    Output file namem
  print, ' KEYWORDS:  
  print, '    /quiet    =    Do not print intermediate results'
  print, '    /help     =    List help.'
  print, '    halfwidth =    halfwidth
  print, '    error     =    <0 if bad
  error = -1
  return
endif

printflag=1
if keyword_set(quiet) then printflag=0
if n_elements(halfwidth) eq 0 then halfwidth = 5
t1   = dt_tm_tojs(systime())
 
if printflag then print, 'Input filename: ' + infile + '.'

if file_test( infile ) eq 0 then begin
   if printflag then begin
     print, 'Cannot find file: ' + infile
     print, 'Exiting ans_sio_image_variance.'
   endif
   error = -1
endif
;
; Read in image
;
ans_ans_read_sio_data, infile, img

v    =  image_variance( img, halfwidth = halfwidth)

;
; Write out variance file
;
sz              = size(v)
sz[1]           = nx
sz[2]           = ny
Scaling         = 1.0
magic_number    = -16678914L
nx              = long(nx)
ny              = long(ny)
data_type       = 3L

if printflag then print, 'Begin writing file :' + outfile

close,  1
openw,  1, outfile
writeu, 1, magic_number, ny, nx, data_type, byte_size
writeu, 1, v
close,  1
t2   = dt_tm_tojs(systime())
if printflag then begin
   print, 'End   writing file :' + outfile
   print, 'Time to read SIO, compute variane, and write out file.' + string(t2-t1) + ' s'
endif



end
