;----------------------------------------------------------
;+
; NAME: ANS_SIO_SUMMARY'
; PURPOSE:'
;   Read SIO data and generate a tab-delimited text file with a summary of sio ancil
;   date information.
; CALLING SEQUENCE:'
;   ans_sio_summary, searchstr, file
; INPUT:'
;   searchstr=    searchstr to look for SIO ancil data.
; OUTPUT:
;   file:         text file with summary information
; KEYWORDS:
;   /quiet=       Do not print intermediate results'
;   /help=        List help.
;   error=        Bad if error less than 0
; MOFICATION HISTORY
;   2012 Jul 31   Frank Monaldo. File created.
; Copyright (C) 2012, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-


pro ans_sio_summary, searchstr, file, $
                     quiet= quiet,    $ 
                     help=  help,     $
                     error= error
                   

if keyword_set(help) or (n_params(0) lt 1) then begin
  print, ' NAME: ANS_SIO_SUMMARY'
  print, ' PURPOSE:'
  print, '   Read SIO data generate a tab-delimited text file with a summary of sio ancil
  print, '   date information.
  print, ' CALLING SEQUENCE:'
  print, '   ans_sio_summary, searchstr, file
  print, ' INPUT:'
  print, '   searchstr=    searchstr to look for SIO ancil data.
  print, ' OUTPUT:
  print, '   file:         text file with summary information
  print, ' KEYWORDS:
  print, '   /quiet=       Do not print intermediate results'
  print, '   /help=        List help.
  print, '   error=        Bad if error less than 0
  return                
endif
;
; Parcing input parameters  
;
printflag= 1
if keyword_set(quiet) then printflag=0

f= file_search(searchstr, count=count)
if count eq 0 then begin
  print, 'Cannot find files that match '+ searchstr + ' .'
  print, 'Exiting ans_sio_summary.'
  error=  -1
  return
endif

n=   n_elements(f)
tab= string(byte(9))


close,  1
openw,  1, file
tt= ' Input file.'                     + tab
tt=   tt + 'Platform name'             + tab
tt=   tt + 'Acquistion Data and Time'  + tab
tt=   tt + 'Upper Left  Lat'           + tab
tt=   tt + 'Upper Left  Lon'           + tab 
tt=   tt + 'Upper Right Lat'           + tab 
tt=   tt + 'Upper Right Lon'           + tab 
tt=   tt + 'Lower Left  Lat'           + tab 
tt=   tt + 'Lower Left  Lon'           + tab 
tt=   tt + 'Lower Right Lat'           + tab 
tt=   tt + 'Lower Right Lon'   
printf, 1, tt

for i=0, n-1 do begin
  ans_read_sio_info, f[i], info, quiet= quiet
  if info.root_file ne '' then begin
     tt=   getwrd( info.root_file, 0, /last, del='/') + tab
     tt=   tt + info.platform_name                    + tab
     tt=   tt + info.acq_date_time                    + tab
     tt=   tt + info.ul_inner_lat                     + tab 
     tt=   tt + info.ul_inner_lon                     + tab 
     tt=   tt + info.ur_inner_lat                     + tab 
     tt=   tt + info.ur_inner_lon                     + tab 
     tt=   tt + info.ll_inner_lat                     + tab 
     tt=   tt + info.ll_inner_lon                     + tab 
     tt=   tt + info.lr_inner_lat                     + tab 
     tt=   tt + info.lr_inner_lon   
     printf, 1, tt
  endif
endfor
close, 1
if printflag then print, 'Summary saved in file: ' + file

end