;-----------------------------------------------------
;+
; NAME: ASF_CHECK4_180
;
; PURPOSE:
;        The purpose of this program is to see if the original
;        image crosses the zero meridian.
; CALLING SEQUENCE:
;    asf_check4_180, lf
; INPUT:
;    lf.corner_ll=  8-element array of outside image corner latitude and
;                   longitudes
; OUTPUT:
;   lf.lngswitchflag=  0     Data *** DOES NOT *** cross 180 deg meridian.
;   lf.lngswitchflag=  1     Data ***   DOES   *** cross 180 deg meridian. 
; KEYWORDS:
;    /quiet=         Print no messages while processing.
;    /help=          Get help.
; MODIFICATION HISTORY:
;   1999 Mar 05  Frank Monaldo  
;   2000 Oct 30 Nathaniel Winstead modified to accommodate lf structure                                    
;   2010 Jun 14 Frank Monaldo. Print help with no parameters.
; Copyright (C) 1999-2010, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro asf_check4_180, lf, help=help, quiet=quiet
		   
if keyword_set(help)  or (n_params(0) lt 1 ) then begin
  print, ' NAME: ASF_CHECK4_180
  print, '
  print, ' PURPOSE:
  print, '        The purpose of this program is to see if the original
  print, '        image crosses the zero meridian.
  print, ' CALLING SEQUENCE:
  print, '    asf_check4_180, lf
  print, ' INPUT:
  print, '    lf.corner_ll=  8-element array of outside image corner latitude and
  print, '                longitudes
  print, ' OUTPUT:
  print, '   lf.lngswitchflag=  0     Data *** DOES NOT *** cross 180 deg meridian.
  print, '   lf.lngswitchflag=  1     Data ***   DOES   *** cross 180 deg meridian. 
  print, ' KEYWORDS:
  print, '    /quiet=         Print no messages while processing.
  print, '    /help=          Get help.
  return
endif
printflag=1
if keyword_set(quiet)   then printflag=0 
if printflag  then print, 'Intermediate results from asf_check4_180.'
;
; Determine if the image cross the 180 meridian
;
lf.lngswitchflag=0
if abs(lf.corner_ll[1]) gt 90 and $
   abs(lf.corner_ll[3]) gt 90 and $
   abs(lf.corner_ll[5]) gt 90 and $
   abs(lf.corner_ll[7]) gt 90 then begin
   signarr=sign([lf.corner_ll[1],lf.corner_ll[3],lf.corner_ll[5],lf.corner_ll[7]])
   maxsign=max(signarr)
   minsign=min(signarr)
   if minsign lt 0 and maxsign gt 0 then begin 
     if printflag gt 1 then print, 'Data crosses 180 meridian'
     lf.lngswitchflag=1
   endif
endif
if lf.lngswitchflag eq 0 then begin
  if printflag then begin
    print, 'lngswitchflag= 0, Use -180/180 deg longitude range.'
    print, lf.corner_ll[1],lf.corner_ll[3],lf.corner_ll[5],lf.corner_ll[7]
  endif
endif else begin
  if printflag then begin
    print, 'lngswitchflag= 1, Use    0/360 deg longitude range.'
    print, lf.corner_ll[1],lf.corner_ll[3],lf.corner_ll[5],lf.corner_ll[7]
  endif
endelse
end
