;-----------------------------------------------------
;+
; NAME: ASF_CREATE_OUTLOC
; PURPOSE:
;    The purpose of this program is to create an outlocate file for use
;    by the ERIM program for i,j <=> lat,lon conversion
;
; CALLING SEQUENCE:
;    asf_create_outloc, lf
; INPUT:
;     lf.n_pixel=      Number of pixels
;     lf.n_line=       Number of lines
;
; OUTPUT:
;     A "outloc_file.txt" with i,j to lat/lon examples
; KEYWORDS=
;     /quiet=          Do not print intermediate results.
;     /help=           List help.
;     position_loc=    Specify fullpath to position_locator executable
;     outputdir=       Directory to store output file
; MODIFICATION HISTORY:
;   1999 Oct 11   Frank Monaldo      
;   2000 Oct 30 Nathaniel Winstead : modified to accommodate lf
;                                    structure
;   2003 Nov 26 Frank Monaldo option to indicate the directory
;                                    position_locator and output
;                                    directory
;   2009 Dec 08  Rewritten for ANSWRS 2.0
;   2009 Dec 21  Output directory in structure
;   2010 Jun 14 Frank Monaldo. Print help if no input. 
;   2010 Dec 29 Frank Monaldo. Suppress screen output of position locator command
; Copyright (C) 1999-2009, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro asf_create_outloc, lf, help=help, quiet=quiet,   $ 
                       position_loc=position_loc
   
if keyword_set(help) or (n_params(0) lt 1 )  then begin
  print, ' NAME: ASF_CREATE_OUTLOC
  print, ' PURPOSE:
  print, '    The purpose of this program is to create an outlocate file for use
  print, '    by the ERIM program for i,j <=> lat,lon conversion
  print, '
  print, ' CALLING SEQUENCE:
  print, '    asf_create_outloc, lf
  print, ' INPUT:
  print, '     lf.n_pixel=      Number of pixels
  print, '     lf.n_line=       Number of lines
  print, '
  print, ' OUTPUT:
  print, '     A "outloc_file.txt" with i,j to lat/lon examples
  print, ' KEYWORDS=
  print, '     /quiet=          Do not print intermediate results.
  print, '     /help=           List help.
  print, '     position_loc=    Specify fullpath to position_locator executable
  return
endif


if n_elements(position_loc) eq 0 then begin
  print, 'Cannot find ' + position_loc
  print, 'We need a position locator executable'
  print, 'Exiting asf_create_outloc;
  return
endif

printflag=1

if keyword_set(quiet)   then printflag=0 
iinc= fix(lf.n_pixel / 11)
jinc= fix(lf.n_line  / 11)

close, 1
openw, 1, lf.working_directory + '/inloc_file.txt'
for i=1L, lf.n_pixel-1, iinc  do begin
  for j=1L, lf.n_line-1, jinc do begin
     output= string(i) + ',' +string(j)
     output= strcompress(output, /remove_all)
     printf,1,output
  endfor 
endfor

close,1
if printflag then print,'Created inloc_file.txt at ' +systime(/utc)
futil, 'temp.meta', /delete
length=  strlen(lf.leaderfile)
rootfile=strmid(lf.leaderfile, 0, length-1)+'D'

cmd= position_loc +' -i -h 0 -x 1 -y 2 ' +  rootfile + ' '  +lf.working_directory + '/inloc_file.txt '
cmd= cmd + lf.working_directory+'/outloc_file.txt'
if printflag then print, cmd
if printflag then begin
  spawn,cmd
endif else begin
  spawn, cmd  + ' > /dev/null'
endelse
if printflag then print,'Created ' + lf.working_directory + '/outloc_file.txt at ' +systime()

end
