;-------------------------------------------------------------
;+
; NAME: ASF_POLY_CAL 
;
; PURPOSE:
;       The program performs a polynomial calculation using 
;       2 input variables.
; CATEGORY:
; CALLING SEQUENCE:
;       out = asf_poly_cal(x, y, coef)
; INPUTS:
;       x=       The first variable
;       y=       The second variable
;       coef=   polynomial coefficients
;
; OUTPUT:
;       out=     polynomial calculation
;      
; KEYWORD PARAMETERS:
;         TOP=t  Max byte value for scaling (def=!d.n_colors-1).
;         /QUIET  Inhibit scaling message.
;
;   Frank Monaldo

; Copyright (C) 1987, Johns Hopkins University/Applied Physics Laboratory
; This software may be used, copied, or redistributed as long as it is not
; sold and this copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied warranties
; whatsoever.  Other limitations apply as described in the file disclaimer.txt.
;-
;-------------------------------------------------------------
 
function asf_poly_cal, x, y, coef,  help=help, quiet=quiet
 
np = n_params(0)

if (np lt 1) or keyword_set(help) then begin
  print, ' NAME: ASF_POLY_CAL 
  print, '
  print, ' PURPOSE:
  print, '       The program performs a polynomial calculation using 
  print, '       2 input variables.
  print, ' CATEGORY:
  print, ' CALLING SEQUENCE:
  print, '       out = ls(x,y,coef)
  print, ' INPUTS:
  print, '       x=       The first variable
  print, '       y=       The second variable
  print, '       coef=   polynomial coefficients
  print, '
  print, ' OUTPUT:
  print, '       out=     polynomial calculation
  print, '      
  print, ' KEYWORD PARAMETERS:
  print, '         TOP=t  Max byte value for scaling (def=!d.n_colors-1).
  print, '         /QUIET  Inhibit scaling message.
  print, '
  return, -1
endif

nc=     n_elements(coef)
deg=    sqrt(nc) - 1
rdeg=   (deg+1)^2-1
out=    0.0
x=double(x)
y=double(y)
if n_elements(x) gt 1 then out=    make_array(size=size(x)) 
if n_elements(y) gt 1 then out=    make_array(size=size(y))  
count=0    
for j=0,deg do begin
  for k=0, deg do begin
   if k ne 0 or j ne 0 then begin
     count=count+1
     out= out + coef[count] * x^j * y^k
     endif
  endfor
endfor
out= out + coef[0]
return, out
end
