;-----------------------------------------------------
;+
; NAME: ASF_READ_DATA_QUAL
;
; PURPOSE:
;        The purpose of this program is read data from the
;        data quality record
; CALLING SEQUENCE:
;
; asf_read_data_qual, lf, /help, /quiet
;
; INPUT:
;    lf.data_quality_summary_rec:     Data set summary record
;
; OUTPUT: following two variables added to lf structure:
;   cal_status:  Status of calibration, "CALIBRATED," "UNCALIBRATED," or 
;                "INFFERED_CAL"
;   cal_comment: Comment on calibration
;
; MODIFICATION HISTORY:
;   1998 jan 15 Frank Monaldo  
;   2000 Oct 30 Nathaniel Winstead 
;   2009 Dec 31 Frank Monaldo . Converted to [ ] for variables.
;   2010 Jan 14 Frank Monaldo. Print help on no input.
; Copyright (C) 1998, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro asf_read_data_qual, lf, help=help, quiet=quiet
		   
if keyword_set(help)  or (n_params(0) lt 1) then begin
  print, ' NAME: ASF_READ_DATA_QUAL
  print, '
  print, ' PURPOSE:
  print, '        The purpose of this program is read data from the
  print, '        data quality record
  print, ' CALLING SEQUENCE:
  print, '
  print, ' asf_read_data_qual, lf, /help, /quiet
  print, '
  print, ' INPUT:
  print, '    lf.data_quality_summary_rec:     Data set summary record
  print, '
  print, ' OUTPUT: added following two variables to lf data structure
  print, '   cal_status:  Status of calibration, "CALIBRATED," "UNCALIBRATED," or 
  print, '                "INFFERED_CAL"
  print, '   cal_comment: Comment on calibration
  print, '  
  return           
endif
printflag=1
if keyword_set(quiet)   then printflag=0 
;
; Determine System Arch
;
arch=!version.arch

;
; Reading data from record
; 
lf.cal_status=      string(lf.data_quality_summary_rec[1382:1397] )
lf.cal_comment=     string(lf.data_quality_summary_rec[1420:1619] )
lf.cal_status=       strcompress(lf.cal_status,/remove_all)
if printflag ne 0 then  begin
  print, ' '
  print, 'Output of asf_read_data_qual'
  print, 'cal_status:     ',lf.cal_status
  print, 'cal_comment:    ',lf.cal_comment
  print, ' '
endif
end
