;-----------------------------------------------------
;+
; NAME: ASF_READ_DATA_SUM
;
; PURPOSE:
;        The purpose of this program is read data from the
;        data summary record
; CALLING SEQUENCE:
;
; asf_read_data_sum, asc_des, plat_lat, plat_long,$
;		     number_of_beams, beam_1_id, $
;                    /help, /quiet
;
; INPUT:
;    lf
;
; OUTPUT: lf with the following elements added:
;    lf.asc_dec:           "ASCENDING" or "DESCENDING"
;    lf.plat_lat:          Platform latitude
;    lf.plat_long:         Platform longitude
;    lf.number_of_beams:  number of beams  ;  1  if std mode
;    lf.beam_1_id:        beam_1_id        ; STx  if std mode
;
; MODIFICATION HISTORY:
;    1998 Dec 10 Frank Monaldo  
;    2000 Oct 30 Nathaniel Winstead  added all output to the lf structure.
;    2008 Feb 02 Frank Monaldo  Read polarization and sar_sensor it lf structure
;    2009 Dec 31 Frank Monaldo. Converted to [ ] for variables.
;    2010 Jun 14 Frank Monaldo. Print help on no input
; Copyright (C) 1998, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro asf_read_data_sum, lf, help=help, quiet=quiet
		   
if keyword_set(help)  or (n_params(0) lt 1) then begin
  print, ' NAME: ASF_READ_DATA_SUM
  print, '
  print, ' PURPOSE:
  print, '        The purpose of this program is read data from the
  print, '        data summary record
  print, ' CALLING SEQUENCE:
  print, '
  print, ' asf_read_data_sum, data_set_summary_rec, lf, $
  print, '                    /help, /quiet
  print, '
  print, ' INPUT:
  print, '    data_set_summary_rec:     Data set summary record
  print, '    lf:                       leader file structure
  print, '
  print, ' OUTPUT: lf with the following elements added:
  print, '    lf.asc_des:          "ASCENDING" or "DESCENDING"
  print, '    lf.plat_lat:         Platform latitude
  print, '    lf.plat_long:        Platform longitude
  print, '    lf.number_of_beams:  number of beams  ;   1  if std mode
  print, '    lf.beam_1_id:        beam_1_id        ; STx  if std mode
  return           
endif
printflag=1
if keyword_set(quiet)   then printflag=0 
;
; Determine System Arch
;
arch=!version.arch
;
; Reading data from record
;
lf.asc_des=                  string(lf.data_set_summary_rec[ 100:115] )
lf.asc_des=           strcompress(lf.asc_des,/remove_all)
lf.plat_lat=          float( string(lf.data_set_summary_rec[ 452: 459] ) )
lf.plat_long=         float( string(lf.data_set_summary_rec[ 460: 467] ) )
lf.number_of_beams=   fix(   string(lf.data_set_summary_rec[1766:1767] ) )
lf.beam_1_id=                string(lf.data_set_summary_rec[1768:1771] )
lf.beam_1_id=         strcompress(lf.beam_1_id,/remove_all)
lf.sar_sensor=        strcompress(lf.data_set_summary_rec[392:400],/remove_all)
if strupcase( strmid(lf.sar_sensor,0,1) ) eq 'R' then lf.sar_sensor='RADARSAT-1'
lf.polarization=      strcompress(lf.data_set_summary_rec[427:429],/remove_all)
if printflag ne 0 then  begin
  print, ' '
  print, 'Output of asf_read_data_sum'
  print, 'asc_des          ', lf.asc_des
  print, 'plat_lat         ', lf.plat_lat
  print, 'plat_long        ', lf.plat_long
  print, 'number_of_beams  ', lf.number_of_beams
  print, 'beam_1_id        ', lf.beam_1_id  
  print, 'sar_sensor       ', lf.sar_sensor
  print, 'polarization     ', lf.polarization
  print, ' '
endif
end
