;;-----------------------------------------------------
;+
; NAME: ENV_WSM_CREATE_LF.PRO
; PURPOSE:
;   The purpose of this program is create a lf structure
;   with general purpose information possible used in
;   processing
; CALLING SEQUENCE
;   env_wsm_create_lf, lf, /help, /quiet
; OUTPUT:
;   lf structure                                   
;
; MODIFICATION HISTORY:
;   2003 Mar 25 Frank Monaldo  
;   2004 Mar 10 Added pixel_spacing, line_spacing,
;               range_pixel, azimuth_pixel,
;               to structure.  This is to accommodate
;               entries into the GAT and ASF leader
;   2004 Aug 06 Added addition elements for Envisat processing
;               Added even more elements for Envisat
;               processing (100)
;   2006 Aug 12 Added addition elements for Envisat processing
;               Added even more elements for Envisat
;               processing (200)
;   2007 Jan 05 Add corner_ll into leader structure
;   2009 Nov 25 Added ave_line, ave_pixel,deg to structure
;   2011 Mar 29 Frank Monaldo. Add nrcs_slope and nrcs_bias
;   2011 May 23 Frank Monaldo. Add jsbegin and jsend to structure
; Copyright (C) 2003-9, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro env_wsm_create_lf, lf, help=help, quiet=quiet

printflag=1
if keyword_set(quiet) then printflag=0

if keyword_set(help)  or (n_params(0) lt 1 ) then begin 
  print, ' NAME: ENV_WSM_CREATE_LF.PRO
  print, ' PURPOSE:
  print, '   The purpose of this program is create a lf structure
  print, '   with general purpose information possible used in
  print, '   processing
  print, ' CALLING SEQUENCE
  print, '   env_wsm_create_lf, lf, /help, /quiet
  print, ' OUTPUT:
  print, '   lf structure                                   
  return
endif

if printflag then begin
  print, 'Declaring lf structure in env_wsm_create_lf program.'
endif

;
; Declaring lf structure
;
lf={ product:                  '',               $        
     productType:              '',               $
     product_stage:            '',               $
     sar_sensor:               'ENVISAT',        $
     scansar:                  1,                $
     asc_des:                  'ASCENDING',      $
     ref_doc:                  '',               $  
     acquistion_station:       '',               $
     proc_cent:                '',               $  
     proc_time:                '',               $  
     software_ver :            '',               $
     sensing_start:            '',               $
     sensing_stop:             '',               $
     data_year:                0,                $
     center_gmt:               '',               $
     month:                    '',               $
     day:                      0,                $
     hour:                     0,                $
     minute:                   0,                $
     second:                   0.0,              $
     abs_orbit:                0.0,              $ 
     state_vector_time:        '',               $
     x_position:               0.0D,             $
     y_position:               0.0D,             $         
     z_position:               0.0D,             $
     x_velocity:               0.0D,             $         
     y_velocity:               0.0D,             $
     z_velocity:               0.0D,             $
     vector_source:               '',            $
     tot_size:                 0L,               $
     sph_size:                 0L,               $
     num_dsd:                  0L,               $
     dsd_size:                 0L,               $
     num_data_sets:            0L,               $
     sph_descriptor:           '',               $  
     first_line_time:          '',               $
     last_line_time:           '',               $
     first_near_lat:           0.0D,             $
     near_start_lat:           0.0D,             $ ; fill in ASF style leader
     first_near_long:          0.0D,             $
     near_start_lon:           0.0D,             $ ; fill in ASF style leader
     first_mid_lat:            0.0D,             $
     first_mid_long:           0.0D,             $
     first_far_lat:            0.0D,             $ 
     far_start_lat:            0.0D,             $ ; fill in ASF style leader
     first_far_long:           0.0D,             $
     far_start_lon:            0.0D,             $ ; fill in ASF style leader
     last_near_lat:            0.0D,             $
     near_end_lat:             0.0D,             $ ; fill in ASF style leader
     last_near_long:           0.0D,             $
     near_end_lon:             0.0D,             $ ; fill in ASF style leader
     last_mid_lat:             0.0D,             $
     last_mid_long:            0.0D,             $
     last_far_lat:             0.0D,             $
     far_end_lat:              0.0D,             $ ; fill in ASF style leader
     last_far_long:            0.0D,             $
     far_end_lon:              0.0D,             $ ; fill in ASF style leader
     center_lon:               0.0,              $ ; fill in ASF style leader
     center_lat:               0.0,              $ ; fill in ASF style leader
     s_c_altitude:             0.0,              $ ; fill in ASF style leader
     pass:                     '',               $
     algorithm:                '',               $
     sample_type:              '',               $
     mds1_tx_rx_polar:         '',               $
     mds2_tx_rx_polar:         '',               $
     compression:              '',               $
     azimuth_looks:            0.0,              $
     range_looks:              0.0,              $
     range_spacing:            0.0,              $
     azimuth_spacing:          0.0,              $
     line_length:              0L,               $
     data_type:                '',               $
     first_line_zero_doppler_time: strarr(500),  $
     line_num:                 ulonarr(500),     $
     num_lines:                ulonarr(500),     $
     sub_sat_track:            fltarr(500),      $
     first_samp_number:        ulonarr(500,11),  $
     first_slant_range_times:  fltarr(500,11),   $
     first_angles:             fltarr(500,11),   $
     first_lats:               fltarr(500,11),   $
     first_longs:              fltarr(500,11),   $ 
     last_line_zero_doppler_time:  strarr(500),  $
     last_samp_number:         ulonarr(500,11),  $
     last_slant_range_times:   fltarr(500,11),   $
     last_angles:              fltarr(500,11),   $
     last_lats:                fltarr(500,11),   $
     last_longs:               fltarr(500,11),   $
     ds_name:                  strarr(500),      $
     ds_type:                  strarr(500),      $
     ds_offset:                lonarr(500),      $
     ds_size:                  lonarr(500),      $
     num_dsr:                  lonarr(500),      $
     dsr_size:                 lonarr(500),      $
     srgr:                     byte(0),          $
     proc_scaling_fact:        fltarr(2),        $
     ext_cal_fact:             fltarr(4),        $ 
     ny0:                      0L,               $
     nx0:                      0L,               $
     ny1:                      0L,               $
     nx1:                      0L,               $
     lngswitchflag:            0,                $
     proc_fac:                 'ESA',            $
     datatake_id:              '',               $   ; fill in ASF style leader
     projection:               'GROUND RANGE',   $   ; fill in ASF style leader
     polarization:             'VV',             $   ; fill in ASF style leader
     leaderfile:                '',              $
     rootfile:                  '',              $   
     pixel_spacing:             0.00,            $   ; fill in GAT style leader    
     line_spacing:              0.00,            $   ; fill in GAT style header  
     range_pixel:               0.00,            $   ; fill in ASF style header
     azimuth_pixel:             0.00,            $
     radar_frequency:           5.3E9,           $   ; GHZ
     radar_band:               'C',              $
     corner_ll:                fltarr(8),        $
     ave_line:                  1L,              $
     ave_pixel:                 1L,              $
     deg:                       2,               $
     nrcs_slope:                1.0,             $
     nrcs_bias:                 0.0,             $
    jsbegin:   -3155673600D,                     $   ; Default setting for start data
    jsend:     -3155673600D                      }   ; Default setting for end  data   
     
end
