;-----------------------------------------------------
;+
; NAME: ENV_WSM_SPECIFC_PRODUCT_HEADER_READ.PRO
; PURPOSE:
;   The purpose of this program is read the specific product
;   header information into leader structure.  After reading this
;   the program will read the Data Set Description (DSD) information.
;   Warning:  The env_wsm_main_product_header_read program
;             must be run first so this program know the number of
;             DSD record to read.
; CALLING SEQUENCE:
;   env_wsm_specific_product_header_read, filename, lf, /help, /quiet
; INPUT:
;  filename:  Filename of ENVISAT file in wide swath medium
;             resolution mode.
;  lf:        Structure to be filled
;             This structure can be generated using program
;             env_wsm_create_lf
; OUTPUT:
;    lf.sph_descriptor=   SPH Descriptor
;    lf.first_line_time=  First zero Doppler Time
;    lf.last_line_time=   Last  zero Doppler Time
;    lf.first_near_lat=   Geodetic latitude  of first sample first line
;    lf.first_near_long=  Geodetic longitude of first sample first line
;    lf.first_mid_lat=    Geodetic latitude  of mid   sample first line
;    lf.first_mid_long=   Geodetic longitude of mid   sample first line
;    lf.first_far_lat=    Geodetic latitude  of last  sample first line
;    lf.first_far_long=   Geodetic longitude of last  sample first line
;    lf.last_near_lat=    Geodetic latitude  of first sample last  line
;    lf.last_near_long=   Geodetic longitude of first sample last  line
;    lf.last_mid_lat=     Geodetic latitude  of mid   sample last  line
;    lf.last_mid_long=    Geodetic longitude of mid   sample last  line
;    lf.last_far_lat=     Geodetic latitude  of last  sample last  line
;    lf.last_far_long=    Geodetic longitude of last  sample last  line
;    lf.pass=             Ascending or descending
;    lf.sample_type=      Sample type, Detected or Complex
;    lf.algorithm=        Processing algorithm used
;    lf.mds1_tx_rx_polar= Transmit/Receive polarization of first  product
;    lf.mds2_tx_rx_polar= Transmit/Receive polarization of second product
;    lf.compression=      Compression algorithm used    
;    lf.azimuth_looks=    Number of azimuth looks
;    lf.range_looks=      Number of range   looks
;    lf.range_spacing=    Range   sample spacing (m)
;    lf.azimuth_spacing=  Azimuth sample spacing (m)
;    lf.line_length=      Number of samples per output line         
;    lf.data_type         Output data type SWORD, UWORD, UBYTE
; KEYWORDS:
;    /quiet=              Produce no intermediate output
;    /help=               Print out help
;    data_set=            Retrieve data for dataset 0 or 1. Default=0
;
; MODIFICATION HISTORY:
;   2003 Mar 25 Frank Monaldo  
;   2010 Jun 14 Frank Monaldo. Print help on no input.
; Copyright (C) 2002-2010, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro env_wsm_specific_product_header_read, filename, lf, $
                    help=help, quiet=quiet,data_set=data_set, error=error
		   
if keyword_set(help)  or (n_params(0) lt 1 ) then begin
  print, ' NAME: ENV_WSM_SPECIFIC_PRODUCT_HEADER_READ.PRO
  print, ' PURPOSE:
  print, '   The purpose of this program is read the specific product
  print, '   header information into leader structure.  After reading this
  print, '   the program will read the Data Set Description (DSD) information.
  print, '   Warning:  The env_wsm_main_product_header_read program
  print, '             must be run first so this program know the number of
  print, '             DSD record to read.
  print, ' CALLING SEQUENCE:
  print, '   env_wsm_specific_product_header_read, filename, lf, /help, /quiet
  print, ' INPUT:
  print, '  filename:  Filename of ENVISAT file in wide swath medium
  print, '             resolution mode.
  print, '  lf:        Structure to be filled.
  print, '             This structure can be generated using program
  print, '             env_wsm_create_lf
  print, ' OUTPUT:
  print, '    lf.sph_descriptor=   SPH Descriptor
  print, '    lf.first_line_time=  First zero Doppler Time
  print, '    lf.last_line_time=   Last  zero Doppler Time
  print, '    lf.first_near_lat=   Geodetic latitude  of first sample first line
  print, '    lf.first_near_long=  Geodetic longitude of first sample first line
  print, '    lf.first_mid_lat=    Geodetic latitude  of mid   sample first line
  print, '    lf.first_mid_long=   Geodetic longitude of mid   sample first line
  print, '    lf.first_far_lat=    Geodetic latitude  of last  sample first line
  print, '    lf.first_far_long=   Geodetic longitude of last  sample first line
  print, '    lf.last_near_lat=    Geodetic latitude  of first sample last  line
  print, '    lf.last_near_long=   Geodetic longitude of first sample last  line
  print, '    lf.last_mid_lat=     Geodetic latitude  of mid   sample last  line
  print, '    lf.last_mid_long=    Geodetic longitude of mid   sample last  line
  print, '    lf.last_far_lat=     Geodetic latitude  of last  sample last  line
  print, '    lf.last_far_long=    Geodetic longitude of last  sample last  line
  print, '    lf.pass=             Ascending or descending
  print, '    lf.sample_type=      Sample type, Detected or Complex
  print, '    lf.algorithm=        Processing algorithm used
  print, '    lf.mds1_tx_rx_polar= Transmit/Receive polarization of first  product
  print, '    lf.mds2_tx_rx_polar= Transmit/Receive polarization of second product
  print, '    lf.compression=      Compression algorithm used    
  print, '    lf.azimuth_looks=    Number of azimuth looks
  print, '    lf.range_looks=      Number of range   looks
  print, '    lf.range_spacing=    Range   sample spacing (m)
  print, '    lf.azimuth_spacing=  Azimuth sample spacing (m)
  print, '    lf.line_length=      Number of samples per output line         
  print, '    lf.data_type         Output data type SWORD, UWORD, UBYTE
  print, ' KEYWORDS:
  print, '    /quiet=              Produce no intermediate output
  print, '    /help=               Print out help
  print, '    data_set=            Retrieve data for dataset 0 or 1. Default=0
  print, '
  return           
endif
printflag=1
if keyword_set(quiet)   then printflag=0 
;
; Determine System Arch
;
arch=!version.arch

error= 1
catch, error_status  
;This statement begins the error handler:  

if Error_status ne 0 then begin  
   print, 'error index: ', error_status  
   print, 'error message: ', !error_state.msg  
   if error_status eq -249  or $
      error_status eq -252  or $
      error_status eq -261  or $
      error_status eq -262  then begin
      error= -1
      return
   endif
   catch, /cancel  
endif  
;
; Reading specific product header record from file.
;
if printflag then print, 'Opening '+ filename + ' to read specific product header'
close, 1
openr, 1, filename
point_lun, 1, 1247 ; Skip over Main Product Header of 1247 bytes
sph=  bytarr(1059)
readu, 1, sph
;
; Leaving file open at this point for later reading of DSD information.
;
;  Reading information from sph record
;
linefeed= string( byte( 10 ) )
lf.sph_descriptor=        string( sph[    0:   45] )
lf.sph_descriptor=        getwrd( lf.sph_descriptor, 0, /last, del='=')
lf.sph_descriptor=        strtrm2( lf.sph_descriptor, 2, linefeed)
lf.sph_descriptor=        strcompress( lf.sph_descriptor )
lf.sph_descriptor=        strtrm2( lf.sph_descriptor, 2, '"')
lf.sph_descriptor=        strcompress( lf.sph_descriptor )
;
lf.first_line_time=       string( sph[  118:  163] )
lf.first_line_time=       getwrd( lf.first_line_time, 0, /last, del='=')
lf.first_line_time=       strtrm2( lf.first_line_time, 2, linefeed)
lf.first_line_time=       strcompress( lf.first_line_time )
lf.first_line_time=       strtrm2( lf.first_line_time, 2, '"')
lf.first_line_time=       strcompress( lf.first_line_time )
;
lf.last_line_time=        string( sph[  164:  208] )
lf.last_line_time=        getwrd( lf.last_line_time, 0, /last, del='=')
lf.last_line_time=        strtrm2( lf.last_line_time, 2, linefeed)
lf.last_line_time=        strcompress( lf.last_line_time )
lf.last_line_time=        strtrm2( lf.last_line_time, 2, '"')
lf.last_line_time=        strcompress( lf.last_line_time )
;
;  FIRST GEOGRAPHIC POSITIONS
;
temp=                     string( sph[  209:  245] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
p=                        strpos(temp,'<')
if p gt -1 then  temp= strep(temp,'D',p, 10)
lf.first_near_lat=        double(temp) * 1e-6
;
temp=                     string( sph[  246:  283] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
p=                        strpos(temp,'<')
if p gt -1 then  temp= strep(temp,'D',p, 10)
lf.first_near_long=       double(temp) * 1e-6
;
;
temp=                     string( sph[  284:  319] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
p=                        strpos(temp,'<')
if p gt -1 then  temp= strep(temp,'D',p, 10)
lf.first_mid_lat=         double(temp) * 1e-6
;
temp=                     string( sph[  320:  356] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
p=                        strpos(temp,'<')
if p gt -1 then  temp= strep(temp,'D',p, 10)
lf.first_mid_long=        double(temp) * 1e-6
;
temp=                     string( sph[  357:  392] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
p=                        strpos(temp,'<')
if p gt -1 then  temp= strep(temp,'D',p, 10)
lf.first_far_lat=        double(temp) * 1e-6
;
;
temp=                     string( sph[  393:  429] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
p=                        strpos(temp,'<')
if p gt -1 then  temp= strep(temp,'D',p, 10)
lf.first_far_long=        double(temp) * 1e-6
;
;  LAST GEOGRAPHICAL POSITIONS
;
temp=                     string( sph[  430:  466] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
p=                        strpos(temp,'<')
if p gt -1 then  temp= strep(temp,'D',p, 10)
lf.last_near_lat=        double(temp) * 1e-6
;
temp=                     string( sph[  467:  502] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
p=                        strpos(temp,'<')
if p gt -1 then  temp= strep(temp,'D',p, 10)
lf.last_near_long=        double(temp) * 1e-6
;
;
temp=                     string( sph[  503:  537] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
p=                        strpos(temp,'<')
if p gt -1 then  temp= strep(temp,'D',p, 10)
lf.last_mid_lat=         double(temp) * 1e-6
;
temp=                     string( sph[  538:  573] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
p=                        strpos(temp,'<')
if p gt -1 then  temp= strep(temp,'D',p, 10)
lf.last_mid_long=        double(temp) * 1e-6
;
temp=                     string( sph[  574:  608] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
p=                        strpos(temp,'<')
if p gt -1 then  temp= strep(temp,'D',p, 10)
lf.last_far_lat=        double(temp) * 1e-6
;
temp=                     string( sph[  609:  644] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
p=                        strpos(temp,'<')
if p gt -1 then  temp= strep(temp,'D',p, 10)
lf.last_far_long=         double(temp) * 1e-6
;
lf.pass=                  string( sph[  693:  710] )
lf.pass=                  getwrd( lf.pass, 0, /last, del='=')
lf.pass=                  strtrm2( lf.pass, 2, linefeed)
lf.pass=                  strcompress( lf.pass )
lf.pass=                  strtrm2( lf.pass, 2, '"')
lf.pass=                  strcompress( lf.pass )
;
lf.sample_type=           string( sph[  711:  733] )
lf.sample_type=           getwrd( lf.sample_type, 0, /last, del='=')
lf.sample_type=           strtrm2( lf.sample_type, 2, linefeed)                 
lf.sample_type=           strcompress( lf.sample_type )
lf.sample_type=           strtrm2( lf.sample_type, 2, '"')
lf.sample_type=           strcompress( lf.sample_type )
;
lf.algorithm=             string( sph[  734:  753] )
lf.algorithm=             getwrd( lf.algorithm, 0, /last, del='=')
lf.algorithm=             strtrm2( lf.algorithm, 2, linefeed)
lf.algorithm=             strcompress( lf.algorithm )
lf.algorithm=             strtrm2( lf.algorithm, 2, '"')
lf.algorithm=             strcompress( lf.algorithm )
;
lf.mds1_tx_rx_polar=      string( sph[  754:  776] )
lf.mds1_tx_rx_polar=      getwrd( lf.mds1_tx_rx_polar, 0, /last, del='=')
lf.mds1_tx_rx_polar=      strtrm2( lf.mds1_tx_rx_polar, 2, linefeed)
lf.mds1_tx_rx_polar=      strcompress( lf.mds1_tx_rx_polar )
lf.mds1_tx_rx_polar=      strtrm2( lf.mds1_tx_rx_polar, 2, '"')
lf.mds1_tx_rx_polar=      strcompress( lf.mds1_tx_rx_polar )
if lf.mds1_tx_rx_polar eq 'H/H'and data_set eq 0  then lf.polarization='H'
;
lf.mds2_tx_rx_polar=      string( sph[  777:  799] )
lf.mds2_tx_rx_polar=      getwrd( lf.mds2_tx_rx_polar, 0, /last, del='=')
lf.mds2_tx_rx_polar=      strtrm2( lf.mds2_tx_rx_polar, 2, linefeed)
lf.mds2_tx_rx_polar=      strcompress( lf.mds2_tx_rx_polar )
lf.mds2_tx_rx_polar=      strtrm2( lf.mds2_tx_rx_polar, 2, '"')
lf.mds2_tx_rx_polar=      strcompress( lf.mds2_tx_rx_polar )
if lf.mds2_tx_rx_polar eq 'H/H'and data_set eq 1  then lf.polarization='H'
;
lf.compression=           string( sph[  800:  819] )
lf.compression=           getwrd( lf.compression, 0, /last, del='=')
lf.compression=           strtrm2( lf.compression, 2, linefeed)
lf.compression=           strcompress( lf.compression )
lf.compression=           strtrm2( lf.compression, 2, '"')
lf.compression=           strcompress( lf.compression )
;
temp=                     string( sph[  820:  838] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
lf.azimuth_looks=   	  float(temp)
;
temp=                     string( sph[  839:  855] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
lf.range_looks=   	  float(temp)
;
temp=                     string( sph[  856:  888] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
p=                        strpos(temp,'<')
if p gt -1 then  temp= strep(temp,'D',p, 3)
lf.range_spacing=   	  float(temp)
;
temp=                     string( sph[  889:  923] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
p=                        strpos(temp,'<')
if p gt -1 then  temp= strep(temp,'D',p, 3)
lf.azimuth_spacing=   	  float(temp)
;
temp=                     string( sph[  962:  989] )
temp=                     getwrd( temp, 0, /last, del='=')
temp=                     strcompress( temp )
temp=                     strtrm2( temp, 2, '"')
temp=                     strcompress( temp )
if p gt -1 then  temp= strep(temp,'D',p, 9)
lf.line_length=   	  long(temp)
;
lf.data_type=             string( sph[  990: 1007] )
lf.data_type=             getwrd( lf.data_type, 0, /last, del='=')
lf.data_type=             strtrm2( lf.data_type, 2, linefeed)
lf.data_type=             strcompress( lf.data_type )
lf.data_type=             strtrm2( lf.data_type, 2, '"')
lf.data_type=             strcompress( lf.data_type )
;
if lf.first_near_lat gt lf.last_near_lat then lf.asc_des='DESCENDING'
if printflag then  begin
  print, ' '
  print, 'lf.sph_descriptor=     ', lf.sph_descriptor  	   
  print, 'lf.first_line_time=    ', lf.first_line_time	
  print, 'lf.last_line_time=     ', lf.last_line_time	
  print, 'lf.first_near_lat (d)= ', lf.first_near_lat
  print, 'lf.first_near_long (d)=', lf.first_near_long	
  print, 'lf.first_mid_lat (d)=  ', lf.first_mid_lat
  print, 'lf.first_mid_long (d)= ', lf.first_mid_long
  print, 'lf.first_far_lat (d)=  ', lf.first_far_lat	
  print, 'lf.first_far_long (d)= ', lf.first_far_long	
  print, 'lf.last_near_lat (d)=  ', lf.last_near_lat	
  print, 'lf.last_near_long (d)= ', lf.last_near_long
  print, 'lf.last_mid_la (d)t=   ', lf.last_mid_lat	
  print, 'lf.last_mid_long (d)=  ', lf.last_mid_long	
  print, 'lf.last_far_lat (d)=   ', lf.last_far_lat	
  print, 'lf.last_far_long (d)=  ', lf.last_far_long
  print, 'lf.pass=               ', lf.pass	
  print, 'lf.algorithm=          ', lf.algorithm	
  print, 'lf.mds1_tx_rx_polar=   ', lf.mds1_tx_rx_polar
  print, 'lf.mds2_tx_rx_polar=   ', lf.mds2_tx_rx_polar	
  print, 'lf.compression=        ', lf.compression
  print, 'lf.azimuth_looks=      ', lf.azimuth_looks
  print, 'lf.range_looks=        ', lf.range_looks
  print, 'lf.range_spacing (m)=  ', lf.range_spacing
  print, 'lf.azimuth_spacing (m)=', lf.azimuth_spacing
  print, 'lf.data_type=          ', lf.data_type
  print, 'lf.asc_des=            ', lf.asc_des
  print, ' '
endif
;
; Read in the DSD records
;
n=    lf.dsd_size * lf.num_dsd  ; number of bytes if DSD information
dsd=  bytarr(n)
;
; Note that the file is still open at the appropriate place
; Now we read all the DSD information into a byte array for further 
; parsing.
;
if printflag then print, 'Reading DSD information..'
readu, 1, dsd
close,1

for i=0, lf.num_dsd-1 do begin
  i0= i * lf.dsd_size
  lf.ds_name[i]=   strcompress(  string( dsd[i0 +   9: i0 +  36]), /remove_all)
  lf.ds_type[i]=                 string( dsd[i0 +  47: i0 +  47])
  lf.ds_offset[i]=         long( string( dsd[i0 + 133: i0 + 153]) ) 
  lf.ds_size[i]=           long( string( dsd[i0 + 170: i0 + 190]) ) 
  lf.num_dsr[i]=           long( string( dsd[i0 + 207: i0 + 217]) ) 
  lf.dsr_size[i]=          long( string( dsd[i0 + 228: i0 + 238]) )
  if printflag then begin
    print, 'ds_name  (' + string(i, format='(I2)') + ')=' + lf.ds_name[i]
    print, 'ds_type  (' + string(i, format='(I2)') + ')=' + lf.ds_type[i]
    print, 'ds_offset(' + string(i, format='(I2)') + ')=' + string(lf.ds_offset[i])
    print, 'ds _size (' + string(i, format='(I2)') + ')=' + string(lf.ds_size[i])
    print, 'num_dsr  (' + string(i, format='(I2)') + ')=' + string(lf.num_dsr[i])
    print, 'dsr_size (' + string(i, format='(I2)') + ')=' + string(lf.dsr_size[i])	   
  endif  
endfor
end
