;-----------------------------------------------------
;+
; NAME: GAT_R_LOOK'
; PURPOSE:'
;  The purpose of this program is to compute the'
;  radar look direction in degrees with respect to '
;  North for ALOS PSAR data..  i.e. 90= east,  '
;  We assume that the data are prsented near range to far range. Earliest'
;  data first We will use the convention of +/- 180
; CALLING SEQUENCE:'
;    gat_r_look, lf
; INPUT:'
;    lf=            Input structure'
; output 
;    lf.rlook_coef added to the lf structure
; KEYWORDS:
;    /quiet=         Print no messages while processing.'
;    /help=          Get help.'
; MODIFICATION HISTORY:
;  2006 Nov 29 Frank Monaldo  
;  2009 Nov 19 Modified for ANSWRS 2.0
;  2009 Dec 12 Converted from psar_r_look
;  2010 Jan 06 Change to use ans_compute_fit
;  2010 Jun 14 Frank Monaldo. Print help on no input.
;  2011 Jan 01 Frank Monaldo. Pass on quiet flag
; Copyright (C) 2006-2010, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro gat_r_look, lf, help=help, quiet=quiet
		   
if keyword_set(help) or (n_params(0) lt 1 ) then begin
  print, ' NAME: GAT_R_LOOK'
  print, ' PURPOSE:'
  print, '  The purpose of this program is to compute the'
  print, '  radar look direction in degrees with respect to '
  print, '  North for ALOS PSAR data..  i.e. 90= east,  '
  print, '  We assume that the data are prsented near range to far range. Earliest'
  print, '  data first We will use the convention of +/- 180
  print, ' CALLING SEQUENCE:'
  print, '    gat_r_look, lf
  print, ' INPUT:'
  print, '    lf=            Input structure'
  print, ' output 
  print, '    lf.rlook_coef added to the lf structure
  print, ' KEYWORDS:
  print, '    /quiet=         Print no messages while processing.'
  print, '    /help=          Get help.'
  return
endif

!quiet=    1
printflag= 1
if keyword_set(quiet)   then printflag=0 
quiet= printflag eq 0


rlook=      dblarr(9)
ii=         [0, lf.nx1/2, lf.nx1-2,        0, lf.nx1/2, lf.nx1-2,        0, lf.nx1/2, lf.nx1-2 ]
jj=         [0,        0,        0, lf.ny1/2, lf.ny1/2, lf.ny1/2, lf.ny1-2, lf.ny1-2, lf.ny1-2 ]
ii=         double(ii)
jj=         double(jj)
for k=0, 8 do begin; loop through fit pints
  ii2=      ii[k]+1D             
  lng0=ans_poly_cal(ii[k], jj[k], lf.lon_coef, lf.lon_xexp, lf.lon_yexp)
  lat0=ans_poly_cal(ii[k], jj[k], lf.lat_coef, lf.lat_xexp, lf.lat_yexp)
  lng1=ans_poly_cal(ii2,   jj[k], lf.lon_coef, lf.lon_xexp, lf.lon_yexp)
  lat1=ans_poly_cal(ii2,   jj[k], lf.lat_coef, lf.lat_xexp, lf.lat_yexp)
  ll2rb, lng0, lat0, lng1, lat1, r, azimuth
  if azimuth gt 180 then azimuth= azimuth - 360.
  rlook[k]= azimuth 
endfor
mean_look= rlook(4)


ans_compute_fit, ii, jj, rlook, lf.deg, rlook_coef, rlook_xexp, rlook_yexp, quiet=quiet



temp_lf= create_struct( lf, 'rlook_coef', rlook_coef, $
                            'rlook_xexp', rlook_xexp, $
                            'rlook_yexp', rlook_yexp )
lf=      0
lf=      temp_lf



end
