;-----------------------------------------------------
;+
; NAME: GAT_READ_DATA_SUM
;
; PURPOSE:
;        The purpose of this program is read data from the
;        data summary record
; CALLING SEQUENCE:
;
; gat_read_data_sum, lf
;
; INPUT:
;    lf:  Leader file structure
; OUTPUT: 
;   lf: updated
;    
; MODIFICATION HISTORY:
;  2001 Mar 01 Frank Monaldo  
;  2009 Dec 14 Frank Monaldo. Read in ellpsoid
;                            range_resolution
;                            azimuth_resolution
;                            range_looks
;                            azimuth_loks
;                            wave_looks
;                            proc_fac
;  2010 Jan 14 Frank Monaldo. Added plat_head to lf structure
;  2010 Jun 14 Frank Monaldo. Print help on no input
; Copyright (C) 2001-2010, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro gat_read_data_sum, lf, help=help, quiet=quiet
		   
if keyword_set(help)  or (n_params(0) lt 1 ) then begin
  print, ' NAME: GAT_READ_DATA_SUM
  print, ' 
  print, ' PURPOSE:
  print, '        The purpose of this program is read data from the
  print, '        data summary record
  print, ' CALLING SEQUENCE:
  print, ' 
  print, ' gat_read_data_sum, lf
  print, ' 
  print, ' INPUT:
  print, '    lf:  Leader file structure
  print, ' OUTPUT: 
  print, '   lf: updated
  return           
endif
printflag=1
if keyword_set(quiet)   then printflag=0 
;
; Reading data from record
;                                                                         
lf.ellipsoid=                 string(lf.data_set_summary_rec[  164: 179] )  
lf.ellip_major=         float(string(lf.data_set_summary_rec[  180: 195] ) )
lf.ellip_minor=         float(string(lf.data_set_summary_rec[  196: 211] ) )
lf.asc_des=       strcompress(string(lf.data_set_summary_rec[ 100:  115] ), /remove_all)
lf.center_gmt=                string(lf.data_set_summary_rec[ 68:    99] )
lf.orbit_num=                 string(lf.data_set_summary_rec[ 444:  451] )
lf.plat_lat=           float( string(lf.data_set_summary_rec[ 452:  459] ) )
lf.plat_long=          float( string(lf.data_set_summary_rec[ 460:  467] ) )
lf.plat_head=          float( string(lf.data_set_summary_rec[ 468:  475] ) )
lf.wavelength=                string(lf.data_set_summary_rec[ 500:  515] )
lf.proc_fac=      strcompress(string(lf.data_set_summary_rec[1046: 1061] ), /remove_all)
lf.azimuth_looks=             string(lf.data_set_summary_rec[1174: 1189] ) 
lf.range_looks=               string(lf.data_set_summary_rec[1190: 1205] ) 
lf.range_resolution=          string(lf.data_set_summary_rec[1350: 1365] ) 
lf.azimuth_resolution=        string(lf.data_set_summary_rec[1366: 1381] ) 
lf.line_spacing=       float( string(lf.data_set_summary_rec[1686: 1701] ) )
lf.pixel_spacing=      float( string(lf.data_set_summary_rec[1702: 1717] ) )
lf.pix_spacing=        float( string(lf.data_set_summary_rec[1702: 1717] ) )


   
;
; Convert center_gmt to a similar format the ASF uses
;
gmt=    lf.center_gmt
year=   strmid(gmt,  0,  4)
month=  strmid(gmt,  4,  2)
day=    strmid(gmt,  6,  2)
hr=     strmid(gmt,  8,  2)
mn=     strmid(gmt, 10,  2)
sc=     strmid(gmt, 12,  5)
sc=     float(sc)/1000.
dn=     ymd2dn(year,month,day)

lf.center_gmt= string(dn, format='(I3.3)') + ':' + $
               hr + ':' + mn + ':' + $
	       string(fix(sc), format='(I2.2)') + '.' +$
	       string((sc-fix(sc))*1000, format='(I3.3)') + ' ' + year
lf.data_year=float(year)
if printflag ne 0 then  begin
  print, ' '
  print, 'Output of gat_read_data_sum'
  print, 'asc_des          ',lf.asc_des
  print, 'center_gmt       ',lf.center_gmt
  print, 'plat_lat         ',lf.plat_lat
  print, 'plat_long        ',lf.plat_long
  print, 'line_spacing     ',lf.line_spacing
  print, 'pixel_spacing    ',lf.pixel_spacing
  print, ' '
endif

end
