;-----------------------------------------------------
;+
; NAME: GAT_READ_DETAIL_PROC
;
; PURPOSE:
;        The purpose of this program is read data from the
;        detailed processing record
; CALLING SEQUENCE:
;
; gat_read_detail_proc, lf
;
; INPUT:
;    lf:  Leader file structure
; OUTPUT: 
;   lf: updated
;    
; MODIFICATION HISTORY:
;   2001 Mar 01 Frank Monaldo  
;   2010 Jun 14 Frank Monaldo. Print help on no input
; Copyright (C) 2001, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro gat_read_detail_proc, lf, help=help, quiet=quiet
		   
if keyword_set(help) or (n_params(0) lt 1 ) then begin
  print, ' NAME: GAT_READ_DETAIL_PROC
  print, '
  print, ' PURPOSE:
  print, '        The purpose of this program is read data from the
  print, '        detailed processing record
  print, ' CALLING SEQUENCE:
  print, '
  print, ' gat_read_detail_proc, lf
  print, '
  print, ' INPUT:
  print, '    lf:  Leader file structure
  print, ' OUTPUT: 
  print, '   lf: updated
  print, '    
  return           
endif
printflag=1
if keyword_set(quiet)   then printflag=0 
;
; Reading data from record
;
lf.eph_orb_data=  float(string(lf.detail_proc_rec[ 4648: 4663] ) )
lf.srgr_coeff[0]= float(string(lf.detail_proc_rec[ 4907: 4922] ) ) 
lf.srgr_coeff[1]= float(string(lf.detail_proc_rec[ 4923: 4938] ) ) 
lf.srgr_coeff[2]= float(string(lf.detail_proc_rec[ 4939: 4954] ) ) 
lf.srgr_coeff[3]= float(string(lf.detail_proc_rec[ 4955: 4970] ) ) 
lf.srgr_coeff[4]= float(string(lf.detail_proc_rec[ 4971: 4986] ) ) 
lf.srgr_coeff[5]= float(string(lf.detail_proc_rec[ 4987: 5002] ) ) 

if printflag ne 0 then  begin
  print, ' '
  print, 'Output of gat_read_detail_proc'
  print, 'eph_orbdata          ',lf.eph_orb_data
  for i=0, 5 do begin
    print, 'srgr_coeff('+ string(i,format='(I1)') + ')= ' + $
            string(lf.srgr_coeff[i], format='(E16.7)' )
  endfor
endif

end
