;-----------------------------------------------------
;+
; NAME: GAT_READ_RAD_DATA
;
; PURPOSE:
;        The purpose of this program is read data from the
;        radiometric data record
; CALLING SEQUENCE:
;
; gat_read_rad_data, lf
;
; INPUT:
;    lf:  Leader file structure
; OUTPUT: 
;   lf: updated
; KEYWORDS:
;  /quiet:       Do not print intermediate output.
;  /help         Print out help.    
; MODIFICATION HISTORY:
;  2001 Mar 01 Frank Monaldo  
;  2010 Jan 01 Frank Monaldo. Print help on no input.
; Copyright (C) 2001-2010, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro gat_read_rad_data, lf, help=help, quiet=quiet
		   
if keyword_set(help) or (n_params(0) lt 1 ) then begin
  print, ' NAME: GAT_READ_RAD_DATA
  print, '
  print, ' PURPOSE:
  print, '        The purpose of this program is read data from the
  print, '        radiometric data record
  print, ' CALLING SEQUENCE:
  print, '
  print, ' gat_read_rad_data, lf
  print, '
  print, ' INPUT:
  print, '    lf:  Leader file structure
  print, ' OUTPUT: 
  print, '   lf: updated
  print, ' KEYWORDS:
  print, '  /quiet:       Do not print intermediate output.
  print, '  /help         Print out help. 
  return           
endif
printflag=1
if keyword_set(quiet)   then printflag=0 

lf.n_samp=   long(string(lf.radiometric_data_rec[60:67]))
lf.samp_inc= long(string(lf.radiometric_data_rec[84:87])) 

for i=0, 511 do begin
  b1=88+i*16 & b2=b1+15
  lf.lookup_tab[i]= float(string(lf.radiometric_data_rec[b1:b2]))
endfor
lf.noise_scale= float(string(lf.radiometric_data_rec[8284:8299])) 
lf.offset=      float(string(lf.radiometric_data_rec[8316:8331])) 
if printflag ne 0 then  begin
  print, ' '
  print, 'Output of gat_read_rad_data'
  print, 'n_samp          ',lf.n_samp
  print, 'samp_inc        ',lf.samp_inc
  print, 'lookup_tab(0)   ',lf.lookup_tab[0]
  print, 'lookup_tab(511) ',lf.lookup_tab[511]
  print, 'noise_scale     ',lf.noise_scale
  print, 'offset=         ',lf.offset
endif
end
