;;-----------------------------------------------------
;+
; NAME: PSAR_CREATE_LF.PRO
; PURPOSE:
;   The purpose of this program is create a lf structure for ALOS PSAR data
;   with general purpose information possible used in
;   processing
; CALLING SEQUENCE
;   psar_create_lf, lf, /help, /quiet
; OUTPUT:
;   lf structure                                   
;
; MODIFICATION HISTORY:
;  2006 Nov 28 Frank Monaldo  
;  2008 Mar 31 Add number_of_sar_channels -FMM
;  2010 Jan 05 Frank Monaldo. Added to lf structure to make compatible with ans_compute_fit
;  2010 Jan 08 Frank Monaldo. Added ellipsoid_designator to structure
;  2010 Jan 20 Frank Monaldo. Set sar_senor to ALOS PALSAR
;                             Make s_c_altitude double precision.
;  2011 Mar 30 Frank Monaldo. Add nrcs_slope and nrcs_bias to structure
;  2011 May 23 Frank Monaldo. Add jsbegin and jsend to structure
;  2012 Oct 30 Frank Monaldo. Print help on no input
; Copyright (C) 2006-2011, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro psar_create_lf, lf, help=help, quiet=quiet

printflag=1
if keyword_set(quiet) then printflag=0

if keyword_set(help)  or (n_params(0) lt 1 )  then begin 
  print, ' NAME: PSAR_CREATE_LF.PRO
  print, ' PURPOSE:
  print, '   The purpose of this program is create a lf structure
  print, '   with general purpose information possible used in
  print, '   processing
  print, ' CALLING SEQUENCE
  print, '   psar_create_lf, lf, /help, /quiet
  print, ' OUTPUT:
  print, '   lf structure                                   
  return
endif
if printflag then begin
  print, 'Declaring lf structure in psar_create_lf program.'
endif

;
; Declaring lf structure
;
lf={ name_dir:                 '',               $
     deg:                      2,                $
     product:                  '',               $        
     product_stage:            '',               $
     sar_sensor:               'ALOS PALSAR',    $
     scene_identifier:         '',               $
     antenna_beam_number:      '',               $
     product_type:             '',               $
     ref_doc:                  '',               $  
     acquistion_station:       '',               $
     proc_cent:                 '',              $  
     proc_time:                '',               $  
     software_ver :            '',               $
     sensing_start:            '',               $
     sensing_stop:             '',               $
     data_year:                0,                $
     center_gmt:               '',               $
     month:                    '',               $
     day:                      0,                $
     hour:                     0,                $
     minute:                   0,                $
     second:                   0.0,              $
     abs_orbit:                0.0,              $ 
     state_vector_time:        '',               $
     x_position:               0.0D,             $
     y_position:               0.0D,             $         
     z_position:               0.0D,             $
     x_velocity:               0.0D,             $         
     y_velocity:               0.0D,             $
     z_velocity:               0.0D,             $
     vector_source:               '',            $
     tot_size:                 0L,               $
     sph_size:                 0L,               $
     num_dsd:                  0L,               $
     dsd_size:                 0L,               $
     num_data_sets:            0L,               $
     sph_descriptor:           '',               $  
     first_line_time:          '',               $
     last_line_time:           '',               $
     first_near_lat:           0.0D,             $
     near_start_lat:           0.0D,             $ ; fill in ASF style leader
     first_near_long:          0.0D,             $
     near_start_lon:           0.0D,             $ ; fill in ASF style leader
     first_mid_lat:            0.0D,             $
     first_mid_long:           0.0D,             $
     first_far_lat:            0.0D,             $ 
     far_start_lat:            0.0D,             $ ; fill in ASF style leader
     first_far_long:           0.0D,             $
     far_start_lon:            0.0D,             $ ; fill in ASF style leader
     last_near_lat:            0.0D,             $
     near_end_lat:             0.0D,             $ ; fill in ASF style leader
     last_near_long:           0.0D,             $
     near_end_lon:             0.0D,             $ ; fill in ASF style leader
     last_mid_lat:             0.0D,             $
     last_mid_long:            0.0D,             $
     last_far_lat:             0.0D,             $
     far_end_lat:              0.0D,             $ ; fill in ASF style leader
     last_far_long:            0.0D,             $
     far_end_lon:              0.0D,             $ ; fill in ASF style leader
     center_lon:               0.0,              $ ; fill in ASF style leader
     center_lat:               0.0,              $ ; fill in ASF style leader
     pass:                     '',               $
     algorithm:                '',               $
     sample_type:              '',               $
     mds1_tx_rx_polar:         '',               $
     mds2_tx_rx_polar:         '',               $
     compression:              '',               $
     azimuth_looks:            0.0,              $
     range_looks:              0.0,              $
     range_spacing:            0.0,              $
     azimuth_spacing:          0.0,              $
     line_length:              0L,               $
     data_type:                '',               $
     first_line_zero_doppler_time: strarr(200),  $
     line_num:                 ulonarr(200),     $
     num_lines:                ulonarr(200),     $
     sub_sat_track:            fltarr(200),      $
     first_samp_number:        ulonarr(200,11),  $
     first_slant_range_times:  fltarr(200,11),   $
     first_angles:             fltarr(200,11),   $
     first_lats:               fltarr(200,11),   $
     first_longs:              fltarr(200,11),   $ 
     last_line_zero_doppler_time:  strarr(200),  $
     last_samp_number:         ulonarr(200,11),  $
     last_slant_range_times:   fltarr(200,11),   $
     last_angles:              fltarr(200,11),   $
     last_lats:                fltarr(200,11),   $
     last_longs:               fltarr(200,11),   $
     ds_name:                  strarr(200),      $
     ds_type:                  strarr(200),      $
     ds_offset:                lonarr(200),      $
     ds_size:                  lonarr(200),      $
     num_dsr:                  lonarr(200),      $
     dsr_size:                 lonarr(200),      $
     srgr:                     byte(0),          $
     proc_scaling_fact:        fltarr(2),        $
     ext_cal_fact:             fltarr(4),        $ 
     ny0:                      0L,               $
     nx0:                      0L,               $
     ny1:                      0L,               $
     nx1:                      0L,               $
     lngswitchflag:            0,                $
     proc_fac:                 'JAXA',           $
     datatake_id:              '',               $   ; fill in ASF style leader
     projection:               'GROUND RANGE',   $   ; fill in ASF style leader
     polarization:             'VV',             $   ; fill in ASF style leader
     leaderfile:                '',              $
     rootfile:                  '',              $   
     pixel_spacing:             0.00,            $   ; fill in GAT style leader    
     line_spacing:              0.00,            $   ; fill in GAT style header  
     range_pixel:               0.00,            $   ; fill in ASF style header
     azimuth_pixel:             0.00,            $
     radar_frequency:           5.3,             $   ; GHZ
     radar_band:               'C',              $
     lon_coef:                  dblarr(6),       $
     lat_coef:                  dblarr(6),       $
     i_coef:                    dblarr(6),       $
     j_coef:                    dblarr(6),       $
     lon_xexp:                  dblarr(6),       $
     lat_xexp:                  dblarr(6),       $
     i_xexp:                    dblarr(6),       $
     j_xexp:                    dblarr(6),       $
     lon_yexp:                  dblarr(6),       $
     lat_yexp:                  dblarr(6),       $
     i_yexp:                    dblarr(6),       $
     j_yexp:                    dblarr(6),       $     
     incid_coefsr:              dblarr(30),      $
     incid_coef:                dblarr(6),       $
     incid_xexp:                dblarr(6),       $
     incid_yexp:                dblarr(6),       $
     corner_ll:                 fltarr(8),       $
     sensor_heading:            0.0,             $ 
     ellipsoid_designator:      '',              $
     semi_major_axis_km:        0.0,             $  
     semi_minor_axis_km:        0.0,             $ 
     sensor_platform_latitude_deg: 0.0,          $   
     geodetic_altitude_km:      0.0,             $
     incidence_angle_at_scence_center: 0.0,      $
     scene_center_line_number:  0.0,             $
     scene_center_pixel_number: 0.0,             $
     scansar:                   '',              $
     asc_des:                   '',              $
     s_c_altitude:              0.0D,            $
     nadir_radius:              0.0,             $
     image_radius:              0.0,             $
     number_of_sar_channels:    1,               $
     reference_ellipsoid:       '',              $
     scale_factor_ellipsoid:    0.00,            $
     map_projection:            '',              $
     distance_to_scene_center_m:'',              $
     datum_shift_parameter_referenced_to_green:  0.0000000, $
     datum_shift_parameter_perpend_to_green:     0.0000000, $
     datum_shift_parameter_direct_rot:           0.0000000, $
     datum_shift_parameter_direct_rot1:          0.0000000, $
     datum_shift_parameter_direct_rot2:          0.0000000, $
     datum_shift_parameter_direct_rot3:          0.0000000, $
     nominal_slant_range_resolution_m:           '',        $
     nominal_slant_azimuth_resolution_m:         '',        $
     receiver_gain_like_polarization:            '',        $
     r_curv:                                     0.0,       $
     orbit_number:              0L,              $
     ave_line:                  1,               $
     ave_pixel:                 1,               $
     slant_range_computed_km:   0.0D,            $
     incidence_angle_at_scene_center: '',        $
     nrcs_slope: 1.0,                            $
     nrcs_bias:  0.0,                            $
    jsbegin:   -3155673600D,                     $   ; Default setting for start data
    jsend:     -3155673600D                      }   ; Default setting for end  data
     
end
