;-----------------------------------------------------
;+
; NAME: PSAR_R_LOOK'
; PURPOSE:'
;  The purpose of this program is to compute the'
;  radar look direction in degrees with respect to '
;  North for ALOS PSAR data..  i.e. 90= east,  '
;  We assume that the data are prsented near range to far range. Earliest'
;  data first We will use the convention of +/- 180
; CALLING SEQUENCE:'
;    psar_r_look, lf
; INPUT:'
;    lf=            Input structure'
; output 
;    lf.rlook_coef added to the lf structure
; KEYWORDS:
;    /quiet=         Print no messages while processing.'
;    /help=          Get help.'
; MODIFICATION HISTORY:
;   2006 Nov 29
;   2009 Nov 19 Frank Monaldo Modified for ANSWRS 2.
;   2009 Dec 23 Frank Monaldo Changed increment to 4 pixels
;               to make sure that we have enough
;               distance to compute a look direction
;   2010 Jan 05 Frank Monaldo. Changed to accommodate ans_compute_fit
;   2010 Jan 07 Frank Monaldo. Increment j component to increment range
;   2010 Jun 14 Frank Monaldo. Print help on no input.
;   2010 Jun 16 Frank Monaldo. Increment in i not j direction
;   2011 Jan 01 Frank Monlado. Pass on quiet flag
; Copyright (C) 2006-2009, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro psar_r_look, lf, help=help, quiet=quiet
		   
if keyword_set(help) or (n_params(0) lt 1 ) then begin
  print, ' NAME: PSAR_R_LOOK'
  print, ' PURPOSE:'
  print, '  The purpose of this program is to compute the'
  print, '  radar look direction in degrees with respect to '
  print, '  North for ALOS PSAR data..  i.e. 90= east,  '
  print, '  We assume that the data are prsented near range to far range. Earliest'
  print, '  data first We will use the convention of +/- 180
  print, ' CALLING SEQUENCE:'
  print, '    psar_r_look, lf
  print, ' INPUT:'
  print, '    lf=            Input structure'
  print, ' output 
  print, '    lf.rlook_coef added to the lf structure
  print, ' KEYWORDS:
  print, '    /quiet=         Print no messages while processing.'
  print, '    /help=          Get help.'
  return
endif
printflag=1
if keyword_set(quiet)   then printflag=0 
quiet= printflag eq 0

rlook=     dblarr(9)
ii=         [4., lf.nx1/2., lf.nx1-5.,        4., lf.nx1/2., lf.nx1-5.,        4., lf.nx1/2., lf.nx1-5. ]
jj=         [4.,        4.,        4., lf.ny1/2., lf.ny1/2., lf.ny1/2., lf.ny1-5., lf.ny1-5., lf.ny1-5. ]
ii=         double(ii)
jj=         double(jj)
increment=  4D
teststr=    strcompress( lf.asc_des, /remove_all)
teststr=    strupcase( teststr )
for k=0, 8 do begin; loop through fit pints
  jj2=      jj[k] + increment             
  lng0=ans_poly_cal(ii[k],             jj[k], lf.lon_coef, lf.lon_xexp, lf.lon_yexp)
  lat0=ans_poly_cal(ii[k],             jj[k], lf.lat_coef, lf.lat_xexp, lf.lat_yexp)
  lng1=ans_poly_cal(ii[k] + increment, jj[k], lf.lon_coef, lf.lon_xexp, lf.lon_yexp)
  lat1=ans_poly_cal(ii[k] + increment, jj[k], lf.lat_coef, lf.lat_xexp, lf.lat_yexp)
  ll2rb, lng0, lat0, lng1, lat1, r, azimuth
  if azimuth gt 180 then azimuth= azimuth - 360.
  rlook[k]= azimuth 
endfor
if printflag then begin
  print, 'lf.asc_des='+lf.asc_des
  print, 'Radar Look Directions:', rlook
endif

mean_look= mean(rlook)

if strupcase( strmid(lf.asc_des,0,1) ) eq 'D'  then rlook= rlook + 180
w= where( rlook gt 180, count)
if count gt 0 then rlook[w]=rlook[w]-360.

if printflag then begin
  print, 'lf.asc_des='+lf.asc_des
  print, 'Radar Look Directions:', rlook
endif

if printflag then print, 'i,j => look angle'
ans_compute_fit, ii,  jj,  rlook, lf.deg,  rlook_coef, rlook_xexp, rlook_yexp, quiet=quiet

temp_lf= create_struct(lf,  'rlook_coef', rlook_coef, $
                            'rlook_xexp', rlook_xexp, $
                            'rlook_yexp', rlook_yexp  )
lf=      0
lf=      temp_lf

end
