;----------------------------------------------------------
;+
; NAME: RCM_SIGMA_NE_FILL'
; PURPOSE:'
;   For RCM sigma_ne is a function of range pixel
;   The input sigma_ne has as many elements as there are
;   range pixel, but only the non-zero values have
;   valid points.   
; CALLING SEQUENCE:'
;   rcm_sigma_ne_fill, lf, ii, noise_level, sigma_ne
; INPUT:'
;   lf            =   leader structure
;   ii            =   index values
;   noise_level   =   array of noise level matching ii
; OUTPUT:
;   sigma_ne      =   Filled in full array of noise_values
; KEYWORDS:
;   /quiet        =   Do not print intermediate results'
;   /help         =   List help.
;   error         =   <0 is failure
; MODIFICATION
;    2018 Jul 20 Frank Monaldo. Creation
; Copyright (C) 20018, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro rcm_sigma_ne_fill, lf, ii, noise_level, sigma_ne, $
                       quiet   =    quiet  , $
                       help    =    help   , $
                       error   =    error


printflag=1
if keyword_set(quiet) then printflag=0
quiet=  printflag eq 0
error = 1

if keyword_set(help)  or (n_params(0) lt 1 )  then begin
  print, ' NAME: RCM_SIGMA_NE_FILL'
  print, ' PURPOSE:'
  print, '   For RCM sigma_ne is a function of range pixel
  print, '   The input sigma_ne has as many elements as there are
  print, '   range pixel, but only the non-zero values have
  print, '   valid points.   
  print, ' CALLING SEQUENCE:'
  print, '   rcm_sigma_ne_fill, lf, ii, noise_level, sigma_ne
  print, ' INPUT:'
  print, '   lf            =   leader structure
  print, '   ii            =   index values
  print, '   noise_level   =   array of noise level matching ii
  print, ' OUTPUT:
  print, '   sigma_ne      =   Filled in full array of noise_values
  print, ' KEYWORDS:
  print, '   /quiet        =   Do not print intermediate results'
  print, '   /help         =   List help.
  print, '   error         =   <0 is failure
  error =  -1
  return
endif

jj            = ulonarr( lf.nx0 )
sigma_ne      = fltarr(  lf.nx0 )
sigma_ne      = interpx(ii, noise_level, jj )


end
