;----------------------------------------------------------
;+
; NAME: RSAT2_FIND_FILES
; PURPOSE: The purpose of this program is to return a the
;          product.xml file. From there we can get the other
;          files names
; CALLING SEQUENCE
;    rsat2_find_files, dir, ff, base_dir
; INPUT
;   dir:      directory to search
; OUTPUT
;   ff:       string of full path to product.xml file.
;   base_dir: full path base_dir of radarsat data
; KEYWORDS:
;  /quiet  Do not print out intermediate results 
;  /help:  Print help'
;  error=error  (0=no error, -1 equal error)
; MODIFICATION HISTORY:
;  2008 May 10 Frank Monaldo
;  2009 Oct 10 Frank Monaldo Only print out info in printflag=1
;  2010 Jun 14 Frank Monaldo Print help on no input.b
;  2013 Feb 05 Frank Monaldo Return base_dir= NONE if not found
; Copyright (C) 1999-2008, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.

pro  rsat2_find_files, dir, ff, base_dir, quiet=quiet, help=help,error=error

printflag=1
if keyword_set(quiet) then printflag=0

if keyword_set(help)  or (n_params(0) lt 1 ) then begin
  print, ' NAME: RSAT2_FIND_FILES
  print, ' PURPOSE: The purpose of this program is to return a the
  print, '          product.xml file. From there we can get the other
  print, '          files names
  print, ' CALLING SEQUENCE
  print, '    rsat2_find_files, dir, ff, base_dir
  print, ' INPUT
  print, '   dir:      directory to search
  print, ' OUTPUT
  print, '   ff:       string of full path to product.xml file.
  print, '   base_dir: full path base_dir of radarsat data
  print, ' KEYWORDS:
  print, '  /quiet  Do not print out intermediate results 
  print, '  /help:  Print help'
  print, '  error=error  (0=no error, -1 equal error)
 return
endif

if printflag then print, 'Looking for RSAT2 data in ' + dir

sys_del='/'


if strmid(dir, strlen(dir)-1,1) ne sys_del  then dir=imagedir+ sys_del


ff=  file_search( dir,'product.xml', count=count)

if count eq 0 then begin
  print , 'There is no ** product.xml file in ' + dir + ' exiting rsat2_find_files'
  base_dir='NONE'
  error=-1
  return
endif

numberofwords= nwrds(  ff[0],  del=sys_del)
fileonly=      getwrd( ff[0],  numberofwords-1, del=sys_del)
res=           strpos( ff[0], fileonly )
base_dir='./'
if res gt -1 then base_dir=strmid( ff[0], 0, res)

if printflag then begin
  print, '---------------------------------------------'
  print, 'Output of rsat2_find_files:'
  print, 'Input directory:      '  + dir
  print, 'Returned file string: '  + ff[0]
  print, 'Base directory;       '  + base_dir
  print, '---------------------------------------------'
endif   
end
