;;-----------------------------------------------------
;+
; NAME: RSAT2_READ_LUTSIGMA
; PURPOSE:
;   Read Sigma Correction
; CALLING SEQUENCE
;  rsat2_read_lutsigma, filename, Bvalue, Avalue
; INPUT
;  filename:       filename with sigma corrections                                
; OUTPUT
;  Bvalue=         Bias
;  Avlaue=         Multiplicaton vlaue
; KEYWORDS:
;  /quiet:         No screen output
;  /help;          Get help
; MODIFICATION HISTORY:
;   2008 May 15  Frank Monaldo  
;   2010 Jun 14 Frank Monaldo. Print help on no input.
; Copyright (C) 2008, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro rsat2_read_lutsigma, filename, Bvalue, Avalue, help=help, quiet=quiet

printflag=1
if keyword_set(quiet) then printflag=0

if keyword_set(help)  or (n_params(0) lt 1 ) then begin
  print, 'NAME: RSAT2_READ_LUTSIGMA
  print, 'PURPOSE:
  print, '  Read Sigma Correction
  print, 'CALLING SEQUENCE
  print, ' rsat2_read_lutsigma, filename, Bvalue, Avalue
  print, 'INPUT
  print, ' filename:       filename with sigma corrections                                
  print, 'OUTPUT
  print, ' Bvalue=         Bias
  print, ' Avlaue=         Multiplicaton vlaue
  print, 'KEYWORDS:
  print, ' /quiet:         No screen output
  print, '  /help;          Get help
  return
endif
res= file_search(filename, count=count)
if count  eq 0 then begin
  print, 'Cannot find file: ' + filename
  print, 'Exiting: rsat)_read_lutsigma' 
  return
endif
if printflag then print, 'Reading gains and offsets for coversion to Radarsat data to sigma.'
s= getfile(filename)
n= n_elements(s)
index= intarr(n)

for i=0, n-1 do index[i]= strpos(s[i], 'offset')
w=where(index ge 0,count)
if count gt 0 then begin
  ss= s(w(0))
  ss= repchr( ss, '<', ' ' ) & ss= repchr( ss, '>', ' ' ) &  ss= repchr( ss, '/', ' ' )
  Bvalue=  strupcase(getwrd(ss, 1))
endif
for i=0L, n-1 do index[i]= strpos(s[i], 'gains')
w=where(index ge 0, count)
if count ge 1 then begin
  ss= s(w(0))
  ss=stress(ss, 'D', 0, '<gains>',  ned)
  ss=stress(ss, 'D', 0, '</gains>', ned)
endif
wordarray, ss, astr
avalue=  double(astr)
bvalue=  double(bvalue)
end
