;----------------------------------------------------------
;+
; NAME: RSAT2_SIGMA_NE_FIT'
; PURPOSE:'
;   For Radarsat-2 sigma_ne is a function of range pixel
;   The input sigma_ne has as many elements as there are
;   range pixel, but only the non-zero values have
;   valid points.  The fit is computed only for those points.
; CALLING SEQUENCE:'
;   rsat2_sigma_ne_fit, lf,  sigma_ne
; INPUT:'
;   lf=           leader structure (updated with coefficients)
;   sigma_ne=     arrat if sigma_ne values
; OUTPUT:
;   lf=           update structe with vales
; KEYWORDS:
;   /quiet=      Do not print intermediate results'
;   /help=       List help.'
; MODIFICATION
;    2011 Aug 14 Frank Monaldo. 
; Copyright (C) 2009, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro rsat2_sigma_ne_fit, lf,  sigma_ne, quiet=quiet, help=help


printflag=1
if keyword_set(quiet) then printflag=0

quiet=  printflag eq 0

if keyword_set(help)  or (n_params(0) lt 1 )  then begin
  print, ' NAME: RSAT2_SIGMA_NE_FIT'
  print, ' PURPOSE:'
  print, '   For Radarsat-2 sigma_ne is a function of range pixel
  print, '   The input sigma_ne has as many elements as there are
  print, '   range pixel, but only the non-zero values have
  print, '   valid points.  The fit is computed only for those points.
  print, ' CALLING SEQUENCE:'
  print, '   rsat2_sigma_ne_fit, lf,  sigma_ne
  print, ' INPUT:'
  print, '   lf=           leader structure (updated with coefficients)
  print, '   sigma_ne=     arrat if sigma_ne values
  print, ' OUTPUT:
  print, '   lf=           update structe with vales
  print, ' KEYWORDS:
  print, '   /quiet=      Do not print intermediate results'
  print, '   /help=       List help.'
  return
endif

n=     lf.deg + 1
coef=  dblarr(n)
w= where(sigma_ne ne 0, count)
;
; Compute fit if there are enough non-zero points
;
if count gt n then begin
 coef=  poly_fit( double(w), double(sigma_ne[w]), lf.deg)
endif
;
; Note that implicitly 
;  coef[0]=  constant term
;  coef[1]=  linear term
;  coef[2]=  quadratic term
;  etc
;
;
; Add coefficients to the lf structure
;
temp_lf= create_struct( lf, 'sigma_ne_coef', coef)
                                                        
lf= 0
lf= temp_lf

end
