;-----------------------------------------------------
;+
; NAME: 
;   SLANT_RANGE_INCID.PRO
; PURPOSE:
;   The purpose of this propram is compute slant range as a function of
;   incident angle
; CALLING SEQUENCE:
;   slant_range_incid, a, b, r_alt, phi, incid, r_s
; INPUTS:
;   a=      Earth semi-major axis in km
;   b=      Earth semi-minor axis in km
;   r_alt=  Geodetic altitude
;   phi=    Latitude (deg)
;   inicid= Incident angle in degrees
; OUTPUTS:
;   r_s=    slant range in km
; KEYWORDS:
;   /quiet:     Print no intermediate output messages.
;   /help:      Print help
; MODIFICATION HISTORY:
;   2007 May 10 Frank Monaldo 
;   2010 Jun 14 Frank Monaldo. Print help on no input.
; Copyright (C) 1998, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
;-
;-----------------------------------------------------
;
pro slant_range_incid, a, b, r_alt, phi, incid, r_s, quiet=quiet,  help=help

if keyword_set(help)  or (n_params(0) lt 1 ) then begin
  print, ' NAME: 
  print, '   SLANT_RANGE_INCID.PRO
  print, ' PURPOSE:
  print, '   The purpose of this propram is compute slant range as a function of
  print, '   incident angle
  print, ' CALLING SEQUENCE:
  print, '   slant_range_incid, a, b, r_alt, phi, incid, r_s
  print, ' INPUTS:
  print, '   a=      Earth semi-major axis in km
  print, '   b=      Earth semi-minor axis in km
  print, '   r_alt=  Geodetic altitude
  print, '   phi=    Latitude (deg)
  print, '   inicid= Incident angle in degrees
  print, ' OUTPUTS:
  print, '   r_s=    slant range in km
  print, ' KEYWORDS:
  print, '   /quiet:     Print no intermediate output messages.
  print, '   /help:      Print help
  return
endif
;
; Convert angles to radians.
;
phi_rad=   phi   * !pi / 180.0
incid_rad= incid * !pi / 180.0
B_rad=     double(!pi - incid_rad)
sin_phi=   sin(phi_rad)
;
; Compute eccentricity
;
e= sqrt( 1 - double(b*b) / a/a )
;
; Compute the radius of curvature.
;
r_curv= a / sqrt( 1 - e * e  * sin_phi * sin_phi)
;
;  We must solve the quadratic equation for r_s
;  r_s^2 - 2 * r_curv cos( B_rad ) * r_s - (2 * r_curv  * r_alt + r_alt^2) = 0
;
aa=   double(1)
bb=   -2 * r_curv  * cos( B_rad )
cc=   -(2 * r_curv  * r_alt + r_alt * r_alt )

quad_form, aa, bb, cc, x1, x2

r_s =x1

if x1 lt 0 then r_s = x2

end
