;;-----------------------------------------------------
;+
; NAME: TSAR_FILLIN_LF.PRO
; PURPOSE:
;   Fill in leader file data from ghead structure
; CALLING SEQUENCE
;   tsar_fillin_lf, ghead, ave_pixel, ave_line, lf,/help, /quiet
; INPUT
;   ghead:     Structure with general header information.
;   ave_pixel: Average columns by this value
;   ave_line:  Average rows by the value
; OUTPUT
;   lf:        Leader file structure
; MODIFICATION HISTORY:
;  2007 Oct 29 Frank Monaldo 
;  2009 Dec 24 Frank Monaldo  Massive re-write and added heading
;  2010 Jun 14 Frank Monaldo. Print help on no input.
;  2011 Jan 01 Frank Monaldo. Pass through quiet flag
;  2011 Mar 30 Frank Monaldo. Add nrcs_slope and nrcs_bias
;  2011 May 27 Frank Monaldo. Add start and stop time.
;  2011 Oct 17 Frank Monaldo. Ellipsoid name set to string not double
;                             Added s_c_altitude to structure
; Copyright (C) 2010-2011, Johns Hopkins University/Applied 
; Physics Laboratory. This software may be used, copied, 
; or redistributed as long as it is not sold and this 
; copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied 
; warranties whatsoever.  
;-

pro tsar_fillin_lf, ghead, layer, ave_pixel, ave_line, lf,  help=help, quiet=quiet

printflag=1
if keyword_set(quiet) then printflag=0
quiet= printflag eq 0

if keyword_set(help)  or (n_params(0) lt 1 ) then begin 
  print, ' NAME: TSAR_FILLIN_LF.PRO
  print, ' PURPOSE:
  print, '   Fill in leader file data from ghead structure
  print, ' CALLING SEQUENCE
  print, '   tsar_fillin_lf, ghead, ave_pixel, ave_line, lf,/help, /quiet
  print, ' INPUT
  print, '   ghead:     Structure with general header information.
  print, '   ave_pixel: Average columns by this value
  print, '   ave_line:  Average rows by the value
  print, ' OUTPUT
  print, '   lf:        Leader file structure
  return
endif
monthstr=[' ', 'jan', 'feb', 'mar', 'apr', 'may', 'jun', $
               'jul', 'aug', 'sep', 'oct', 'nov',  'dec']
;
; Declaring lf structure
;
lf={ name_dir:                 '',               $
     product:                  '',               $        
     product_stage:            '',               $
     producttype:              '',               $
     beam_mode:                '',               $
     sar_sensor:               '',               $
     ref_doc:                  '',               $  
     acquistion_station:       '',               $
     proc_cent:                '',               $  
     proc_time:                '',               $  
     software_ver :            '',               $
     sensing_start:            '',               $
     sensing_stop:             '',               $
     data_year:                0,                $
     center_gmt:               '',               $
     month:                    '',               $
     day:                      0,                $
     hour:                     0,                $
     minute:                   0,                $
     second:                   0.0,              $
     absorbit:                 0.0,              $ 
     state_vector_time:        '',               $
     x_position:               0.0D,             $
     y_position:               0.0D,             $         
     z_position:               0.0D,             $
     x_velocity:               0.0D,             $         
     y_velocity:               0.0D,             $
     z_velocity:               0.0D,             $
     s_c_altitude:             0.0D,             $
     vector_source:               '',            $
     tot_size:                 0L,               $
     sph_size:                 0L,               $
     num_dsd:                  0L,               $
     dsd_size:                 0L,               $
     num_data_sets:            0L,               $
     sph_descriptor:           '',               $  
     first_line_time:          '',               $
     last_line_time:           '',               $
     first_near_lat:           0.0D,             $
     near_start_lat:           0.0D,             $ ; fill in ASF style leader
     first_near_long:          0.0D,             $
     near_start_lon:           0.0D,             $ ; fill in ASF style leader
     first_mid_lat:            0.0D,             $
     first_mid_long:           0.0D,             $
     first_far_lat:            0.0D,             $ 
     far_start_lat:            0.0D,             $ ; fill in ASF style leader
     first_far_long:           0.0D,             $
     far_start_lon:            0.0D,             $ ; fill in ASF style leader
     last_near_lat:            0.0D,             $
     near_end_lat:             0.0D,             $ ; fill in ASF style leader
     last_near_long:           0.0D,             $
     near_end_lon:             0.0D,             $ ; fill in ASF style leader
     last_mid_lat:             0.0D,             $
     last_mid_long:            0.0D,             $
     last_far_lat:             0.0D,             $
     far_end_lat:              0.0D,             $ ; fill in ASF style leader
     last_far_long:            0.0D,             $
     far_end_lon:              0.0D,             $ ; fill in ASF style leader
     center_lon:               0.0,              $ ; fill in ASF style leader
     center_lat:               0.0,              $ ; fill in ASF style leader
     pass:                     '',               $
     algorithm:                '',               $
     sample_type:              '',               $
     compression:              '',               $
     azimuth_looks:            0.0,              $
     range_looks:              0.0,              $
     range_spacing:            0.0,              $
     azimuth_spacing:          0.0,              $
     line_length:              0L,               $
     data_type:                '',               $
     first_line_zero_doppler_time: strarr(500),  $
     line_num:                 ulonarr(500),     $
     num_lines:                ulonarr(500),     $
     sub_sat_track:            fltarr(500),      $
     first_samp_number:        ulonarr(500,11),  $
     first_slant_range_times:  fltarr(500,11),   $
     first_angles:             fltarr(500,11),   $
     first_lats:               fltarr(500,11),   $
     first_longs:              fltarr(500,11),   $ 
     last_line_zero_doppler_time:  strarr(500),  $
     last_samp_number:         ulonarr(500,11),  $
     last_slant_range_times:   fltarr(500,11),   $
     last_angles:              fltarr(500,11),   $
     last_lats:                fltarr(500,11),   $
     last_longs:               fltarr(500,11),   $
     ds_name:                  strarr(500),      $
     ds_type:                  strarr(500),      $
     ds_offset:                lonarr(500),      $
     ds_size:                  lonarr(500),      $
     num_dsr:                  lonarr(500),      $
     dsr_size:                 lonarr(500),      $
     srgr:                     byte(0),          $
     proc_scaling_fact:        fltarr(2),        $
     ext_cal_fact:             fltarr(4),        $ 
     ny0:                      0L,               $
     nx0:                      0L,               $
     ny1:                      0L,               $
     nx1:                      0L,               $
     lngswitchflag:            0,                $
     proc_fac:                 'TSAR',           $
     datatake_id:              '',               $   ; fill in ASF style leader
     projection:               'GROUND RANGE',   $   ; fill in ASF style leader
     polarization:             'VV',             $   ; fill in ASF style leader
     pollayer:                  strarr(4),       $
     leaderfile:                '',              $
     rootfile:                  '',              $   
     pixel_spacing:             0.00,            $   ; fill in GAT style leader    
     line_spacing:              0.00,            $   ; fill in GAT style header  
     range_pixel:               0.00,            $   ; fill in ASF style header
     azimuth_pixel:             0.00,            $
     radar_frequency:           '9.65',          $   ; GHZ
     radar_band:               'X',              $
     layer:                     0,               $
     corner_ll:                fltarr(8),        $
     orbitdirection:           '',               $
     imagedatafiles:           strarr(4),        $
     base_directory:           '',               $
     lookdirection:            'RIGHT',          $
     groundRangeResolution:    '',               $
     azimuthResolution:        '',               $
     azimuthLooks:             '',               $
     rangeLooks:               '',               $
     heading:                  '' ,              $
     rlook:                    '' ,              $
     nrcs_slope:               1.0,              $
     nrcs_bias:                0.0,              $
     ellipsoidName:            '',               $       
     semiMajorAxis:            double(0),        $       
     semiMinorAxis:            double(0),        $       
     datumshiftparameters:     double([0,0,0]),  $
     jsbegin:                  -3155673600D,     $
     jsend:                    -3155673600D      }
     
     
;-------------------------------------------------------------
; Popluating the lf structure. Unfilled values remarked out.
;-------------------------------------------------------------
;
lf.name_dir=               ghead.mainfile[0]
lf.product=                ghead.mission
lf.sar_sensor=             ghead.mission
lf.producttype=            ghead.producttype
lf.beam_mode=              ghead.imagingMode
lf.ref_doc=                ghead.generationsystem + ghead.generationsystemversion
lf.acquistion_station=     ghead.source
lf.proc_cent=              ghead.source
lf.proc_time=              ghead.generationtime
lf.software_ver=           ghead.generationsystemversion

                            
lf.groundRangeResolution=  ghead.groundRangeResolution 
lf.azimuthResolution=      ghead.azimuthResolution     
lf.azimuthLooks=           ghead.azimuthLooks          
lf.rangeLooks=             ghead.rangeLooks            
     

start_date=                getwrd( ghead.STARTTIMEUTC, 0, del='T')
start_time=                getwrd( ghead.STARTTIMEUTC, 1, del='T')
start_time=                strmid( start_time, 0, 12)
start_year=                getwrd( start_date, 0, del='-')
start_month=               getwrd( start_date, 1, del='-')
start_month_str=           monthstr( fix(start_month) )   
start_day=                 getwrd( start_date, 2, del='-')
start_js=                  dt_tm_tojs(start_year + '  ' + start_month_str +  ' ' + start_day + $
                                     ' ' + start_time)
lf.jsbegin=                start_js                                    
end_date=                  getwrd( ghead.STOPTIMEUTC, 0, del='T')
end_time=                  getwrd( ghead.STOPTIMEUTC, 1, del='T')
end_time=                  strmid( end_time, 0, 12)
end_year=                  getwrd( end_date, 0, del='-')
end_month=                 getwrd( end_date, 1, del='-')
end_month_str=             monthstr( fix(end_month) )   
end_day=                   getwrd( end_date, 2, del='-')
end_js=                    dt_tm_tojs(end_year + '  ' + end_month_str +  ' ' + end_day + $
                                       ' ' +  end_time)
lf.jsend=                  end_js                                         
                                       
center_time_js=            (start_js + end_js) /2.0

lf.data_year=              fix(dt_tm_fromjs(center_time_js,format='Y$'))
lf.month=                  strlowcase(dt_tm_fromjs(center_time_js,format='n$'))
lf.day=                    fix(dt_tm_fromjs(center_time_js,format='d$'))
lf.hour=                   fix(dt_tm_fromjs(center_time_js,format='h$'))
lf.minute=                 fix(dt_tm_fromjs(center_time_js,format='m$'))
lf.second=                 fix(dt_tm_fromjs(center_time_js,format='s$'))
lf.center_gmt=             dt_tm_fromjs(center_time_js,format='doy$')   + ':' + $
                           string(lf.hour,      format='(I2.2)')        + ':' + $
                           string(lf.minute,    format='(I2.2)')        + ':' + $
                           string(lf.second,    format='(I2.2)')        + ' ' + $
                           string(lf.data_year, format='(I4.4)')      
lf.orbitdirection=         ghead.orbitdirection 
lf.heading=                ghead.headingAngle
lf.absorbit=               fix(ghead.absorbit) 
lf.center_lon=             float(ghead.centerlon)
lf.center_lat=             float(ghead.centerlat)
lf.algorithm=              'XMOD0'
lf.ext_cal_fact=           float( ghead.calfactor[0:3])
lf.nx0=                    long(ghead.NUMBEROFCOLUMNS)
lf.ny0=                    long(ghead.NUMBEROFROWS)
lf.nx1=                    lf.nx0 / ave_pixel
lf.ny1=                    lf.ny0 / ave_line
lf.lngswitchflag=           0
lf.proc_fac=               'DLR'
lf.projection=             ghead.projection
lf.polarization=           ghead.pollayer[0]
lf.pollayer=               ghead.pollayer[0:3]
lf.leaderfile=             getwrd(ghead.mainfile[0], 0, /last, del='/')
lf.rootfile=               getwrd(ghead.IMAGEDATAFILE[0], 0, /last, del='/') 
lf.imagedatafiles=         ghead.IMAGEDATAFILE[0:3] 
lf.pixel_spacing=          float(ghead.columnspacing)
lf.line_spacing=           float(ghead.rowspacing)
lf.range_pixel=            lf.pixel_spacing
lf.azimuth_pixel=          lf.line_spacing
lf.radar_frequency=        (float(ghead.centerfrequency) / 1E9)
lf.radar_frequency=        strcompress(lf.radar_frequency, /remove_all)
lf.radar_band=             'X'
lf.corner_ll=              float([ghead.cornerlat[0], $
                                  ghead.cornerlon[0], $ 
                                  ghead.cornerlat[1], $
                                  ghead.cornerlon[1], $ 
                                  ghead.cornerlat[2], $
                                  ghead.cornerlon[2], $ 
                                  ghead.cornerlat[3], $
                                  ghead.cornerlon[3]] )
       
lf.near_start_lat=        ghead.cornerlat[0]
lf.near_start_lon=        ghead.cornerlon[0]
lf.far_start_lat=         ghead.cornerlat[1]
lf.far_start_lon=         ghead.cornerlon[1]
lf.near_end_lat=          ghead.cornerlat[2]
lf.near_end_lon=          ghead.cornerlon[2]
lf.far_end_lat=           ghead.cornerlat[3]
lf.far_end_lon=           ghead.cornerlon[3]     
lf.lookdirection=         ghead.lookdirection


asf_check4_180, lf, quiet=quiet

end
